#define	or 	||
#define bitor	|
#define or_eq	!=
#define	xor	^
#define	xor_eq	^=
#define	compl	~
#define	and	&&
#define	bitand	&
#define	and_eq	&=
#define	not	!
#define	not_eq	!=
#define	diff	!=

/*	#define	begin	{
	#define end 	}
*/

#define ARRAY(A)	[ A ]
