   Repertoire according to ISO/IEC DIS.2 10646 JTC1/SC2/WG2 N783 19911226
   keld@dkuug.dk 1992-01-18
   group 000
   Plane 000
   row 000
   cell 032
SP SPACE
!  EXCLAMATION MARK
"  QUOTATION MARK
Nb NUMBER SIGN
DO DOLLAR SIGN
%  PERCENT SIGN
&  AMPERSAND
'  APOSTROPHE
(  LEFT PARENTHESIS
)  RIGHT PARENTHESIS
*  ASTERISK
+  PLUS SIGN
,  COMMA
-  HYPHEN-MINUS
.  FULL STOP
/  SOLIDUS
0  DIGIT ZERO
1  DIGIT ONE
2  DIGIT TWO
3  DIGIT THREE
4  DIGIT FOUR
5  DIGIT FIVE
6  DIGIT SIX
7  DIGIT SEVEN
8  DIGIT EIGHT
9  DIGIT NINE
:  COLON
;  SEMICOLON
<  LESS-THAN SIGN
=  EQUALS SIGN
>  GREATER-THAN SIGN
?  QUESTION MARK
At COMMERCIAL AT
A  LATIN CAPITAL LETTER A
B  LATIN CAPITAL LETTER B
C  LATIN CAPITAL LETTER C
D  LATIN CAPITAL LETTER D
E  LATIN CAPITAL LETTER E
F  LATIN CAPITAL LETTER F
G  LATIN CAPITAL LETTER G
H  LATIN CAPITAL LETTER H
I  LATIN CAPITAL LETTER I
J  LATIN CAPITAL LETTER J
K  LATIN CAPITAL LETTER K
L  LATIN CAPITAL LETTER L
M  LATIN CAPITAL LETTER M
N  LATIN CAPITAL LETTER N
O  LATIN CAPITAL LETTER O
P  LATIN CAPITAL LETTER P
Q  LATIN CAPITAL LETTER Q
R  LATIN CAPITAL LETTER R
S  LATIN CAPITAL LETTER S
T  LATIN CAPITAL LETTER T
U  LATIN CAPITAL LETTER U
V  LATIN CAPITAL LETTER V
W  LATIN CAPITAL LETTER W
X  LATIN CAPITAL LETTER X
Y  LATIN CAPITAL LETTER Y
Z  LATIN CAPITAL LETTER Z
<( LEFT SQUARE BRACKET
// REVERSE SOLIDUS
)> RIGHT SQUARE BRACKET
'> CIRCUMFLEX ACCENT
_  LOW LINE
'! GRAVE ACCENT
a  LATIN SMALL LETTER A
b  LATIN SMALL LETTER B
c  LATIN SMALL LETTER C
d  LATIN SMALL LETTER D
e  LATIN SMALL LETTER E
f  LATIN SMALL LETTER F
g  LATIN SMALL LETTER G
h  LATIN SMALL LETTER H
i  LATIN SMALL LETTER I
j  LATIN SMALL LETTER J
k  LATIN SMALL LETTER K
l  LATIN SMALL LETTER L
m  LATIN SMALL LETTER M
n  LATIN SMALL LETTER N
o  LATIN SMALL LETTER O
p  LATIN SMALL LETTER P
q  LATIN SMALL LETTER Q
r  LATIN SMALL LETTER R
s  LATIN SMALL LETTER S
t  LATIN SMALL LETTER T
u  LATIN SMALL LETTER U
v  LATIN SMALL LETTER V
w  LATIN SMALL LETTER W
x  LATIN SMALL LETTER X
y  LATIN SMALL LETTER Y
z  LATIN SMALL LETTER Z
(! LEFT CURLY BRACKET
!! VERTICAL LINE
!) RIGHT CURLY BRACKET
'? TILDE
   cell 160
NS NO-BREAK SPACE
!I INVERTED EXCLAMATION MARK
Ct CENT SIGN
Pd POUND SIGN
Cu CURRENCY SIGN
Ye YEN SIGN
BB BROKEN BAR
SE SECTION SIGN
': DIAERESIS
Co COPYRIGHT SIGN
-a FEMININE ORDINAL INDICATOR
<< LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
NO NOT SIGN
-- SOFT HYPHEN
Rg REGISTERED SIGN
'm MACRON
DG DEGREE SIGN
+- PLUS-MINUS SIGN
2S SUPERSCRIPT TWO
3S SUPERSCRIPT THREE
'' ACUTE ACCENT
My MICRO SIGN
PI PILCROW SIGN
.M MIDDLE DOT
', CEDILLA
1S SUPERSCRIPT ONE
-o MASCULINE ORDINAL INDICATOR
>> RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
14 VULGAR FRACTION ONE QUARTER
12 VULGAR FRACTION ONE HALF
34 VULGAR FRACTION THREE QUARTERS
?I INVERTED QUESTION MARK
A! LATIN CAPITAL LETTER A WITH GRAVE
A' LATIN CAPITAL LETTER A WITH ACUTE
A> LATIN CAPITAL LETTER A WITH CIRCUMFLEX
A? LATIN CAPITAL LETTER A WITH TILDE
A: LATIN CAPITAL LETTER A WITH DIAERESIS
AA LATIN CAPITAL LETTER A WITH RING ABOVE
AE LATIN CAPITAL LETTER AE
C, LATIN CAPITAL LETTER C WITH CEDILLA
E! LATIN CAPITAL LETTER E WITH GRAVE
E' LATIN CAPITAL LETTER E WITH ACUTE
E> LATIN CAPITAL LETTER E WITH CIRCUMFLEX
E: LATIN CAPITAL LETTER E WITH DIAERESIS
I! LATIN CAPITAL LETTER I WITH GRAVE
I' LATIN CAPITAL LETTER I WITH ACUTE
I> LATIN CAPITAL LETTER I WITH CIRCUMFLEX
I: LATIN CAPITAL LETTER I WITH DIAERESIS
D- LATIN CAPITAL LETTER ETH (Icelandic)
N? LATIN CAPITAL LETTER N WITH TILDE
O! LATIN CAPITAL LETTER O WITH GRAVE
O' LATIN CAPITAL LETTER O WITH ACUTE
O> LATIN CAPITAL LETTER O WITH CIRCUMFLEX
O? LATIN CAPITAL LETTER O WITH TILDE
O: LATIN CAPITAL LETTER O WITH DIAERESIS
*X MULTIPLICATION SIGN
O/ LATIN CAPITAL LETTER O WITH STROKE
U! LATIN CAPITAL LETTER U WITH GRAVE
U' LATIN CAPITAL LETTER U WITH ACUTE
U> LATIN CAPITAL LETTER U WITH CIRCUMFLEX
U: LATIN CAPITAL LETTER U WITH DIAERESIS
Y' LATIN CAPITAL LETTER Y WITH ACUTE
TH LATIN CAPITAL LETTER THORN (Icelandic)
ss LATIN SMALL LETTER SHARP S (German)
a! LATIN SMALL LETTER A WITH GRAVE
a' LATIN SMALL LETTER A WITH ACUTE
a> LATIN SMALL LETTER A WITH CIRCUMFLEX
a? LATIN SMALL LETTER A WITH TILDE
a: LATIN SMALL LETTER A WITH DIAERESIS
aa LATIN SMALL LETTER A WITH RING ABOVE
ae LATIN SMALL LETTER AE
c, LATIN SMALL LETTER C WITH CEDILLA
e! LATIN SMALL LETTER E WITH GRAVE
e' LATIN SMALL LETTER E WITH ACUTE
e> LATIN SMALL LETTER E WITH CIRCUMFLEX
e: LATIN SMALL LETTER E WITH DIAERESIS
i! LATIN SMALL LETTER I WITH GRAVE
i' LATIN SMALL LETTER I WITH ACUTE
i> LATIN SMALL LETTER I WITH CIRCUMFLEX
i: LATIN SMALL LETTER I WITH DIAERESIS
d- LATIN SMALL LETTER ETH (Icelandic)
n? LATIN SMALL LETTER N WITH TILDE
o! LATIN SMALL LETTER O WITH GRAVE
o' LATIN SMALL LETTER O WITH ACUTE
o> LATIN SMALL LETTER O WITH CIRCUMFLEX
o? LATIN SMALL LETTER O WITH TILDE
o: LATIN SMALL LETTER O WITH DIAERESIS
-: DIVISION SIGN
o/ LATIN SMALL LETTER O WITH STROKE
u! LATIN SMALL LETTER U WITH GRAVE
u' LATIN SMALL LETTER U WITH ACUTE
u> LATIN SMALL LETTER U WITH CIRCUMFLEX
u: LATIN SMALL LETTER U WITH DIAERESIS
y' LATIN SMALL LETTER Y WITH ACUTE
th LATIN SMALL LETTER THORN (Icelandic)
y: LATIN SMALL LETTER Y WITH DIAERESIS

   row 001
   cell 000
A- LATIN CAPITAL LETTER A WITH MACRON
a- LATIN SMALL LETTER A WITH MACRON
A( LATIN CAPITAL LETTER A WITH BREVE
a( LATIN SMALL LETTER A WITH BREVE
A; LATIN CAPITAL LETTER A WITH OGONEK
a; LATIN SMALL LETTER A WITH OGONEK
C' LATIN CAPITAL LETTER C WITH ACUTE
c' LATIN SMALL LETTER C WITH ACUTE
C> LATIN CAPITAL LETTER C WITH CIRCUMFLEX
c> LATIN SMALL LETTER C WITH CIRCUMFLEX
C. LATIN CAPITAL LETTER C WITH DOT ABOVE
c. LATIN SMALL LETTER C WITH DOT ABOVE
C< LATIN CAPITAL LETTER C WITH CARON
c< LATIN SMALL LETTER C WITH CARON
D< LATIN CAPITAL LETTER D WITH CARON
d< LATIN SMALL LETTER D WITH CARON
D/ LATIN CAPITAL LETTER D WITH STROKE
d/ LATIN SMALL LETTER D WITH STROKE
E- LATIN CAPITAL LETTER E WITH MACRON
e- LATIN SMALL LETTER E WITH MACRON
E( LATIN CAPITAL LETTER E WITH BREVE
e( LATIN SMALL LETTER E WITH BREVE
E. LATIN CAPITAL LETTER E WITH DOT ABOVE
e. LATIN SMALL LETTER E WITH DOT ABOVE
E; LATIN CAPITAL LETTER E WITH OGONEK
e; LATIN SMALL LETTER E WITH OGONEK
E< LATIN CAPITAL LETTER E WITH CARON
e< LATIN SMALL LETTER E WITH CARON
G> LATIN CAPITAL LETTER G WITH CIRCUMFLEX
g> LATIN SMALL LETTER G WITH CIRCUMFLEX
G( LATIN CAPITAL LETTER G WITH BREVE
g( LATIN SMALL LETTER G WITH BREVE
G. LATIN CAPITAL LETTER G WITH DOT ABOVE
g. LATIN SMALL LETTER G WITH DOT ABOVE
G, LATIN CAPITAL LETTER G WITH CEDILLA
g, LATIN SMALL LETTER G WITH CEDILLA
H> LATIN CAPITAL LETTER H WITH CIRCUMFLEX
h> LATIN SMALL LETTER H WITH CIRCUMFLEX
H/ LATIN CAPITAL LETTER H WITH STROKE
h/ LATIN SMALL LETTER H WITH STROKE
I? LATIN CAPITAL LETTER I WITH TILDE
i? LATIN SMALL LETTER I WITH TILDE
I- LATIN CAPITAL LETTER I WITH MACRON
i- LATIN SMALL LETTER I WITH MACRON
I( LATIN CAPITAL LETTER I WITH BREVE
i( LATIN SMALL LETTER I WITH BREVE
I; LATIN CAPITAL LETTER I WITH OGONEK
i; LATIN SMALL LETTER I WITH OGONEK
I. LATIN CAPITAL LETTER I WITH DOT ABOVE
i. LATIN SMALL LETTER I DOTLESS
IJ LATIN CAPITAL LIGATURE IJ
ij LATIN SMALL LIGATURE IJ
J> LATIN CAPITAL LETTER J WITH CIRCUMFLEX
j> LATIN SMALL LETTER J WITH CIRCUMFLEX
K, LATIN CAPITAL LETTER K WITH CEDILLA
k, LATIN SMALL LETTER K WITH CEDILLA
kk LATIN SMALL LETTER KRA (Greenlandic)
L' LATIN CAPITAL LETTER L WITH ACUTE
l' LATIN SMALL LETTER L WITH ACUTE
L, LATIN CAPITAL LETTER L WITH CEDILLA
l, LATIN SMALL LETTER L WITH CEDILLA
L< LATIN CAPITAL LETTER L WITH CARON
l< LATIN SMALL LETTER L WITH CARON
L. LATIN CAPITAL LETTER L WITH MIDDLE DOT
l. LATIN SMALL LETTER L WITH MIDDLE DOT
L/ LATIN CAPITAL LETTER L WITH STROKE
l/ LATIN SMALL LETTER L WITH STROKE
N' LATIN CAPITAL LETTER N WITH ACUTE
n' LATIN SMALL LETTER N WITH ACUTE
N, LATIN CAPITAL LETTER N WITH CEDILLA
n, LATIN SMALL LETTER N WITH CEDILLA
N< LATIN CAPITAL LETTER N WITH CARON
n< LATIN SMALL LETTER N WITH CARON
'n LATIN SMALL LETTER N PRECEDED BY APOSTROPHE
NG LATIN CAPITAL LETTER ENG (Lappish)
ng LATIN SMALL LETTER ENG (Lappish)
O- LATIN CAPITAL LETTER O WITH MACRON
o- LATIN SMALL LETTER O WITH MACRON
O( LATIN CAPITAL LETTER O WITH BREVE
o( LATIN SMALL LETTER O WITH BREVE
O" LATIN CAPITAL LETTER O WITH DOUBLE ACUTE 
o" LATIN SMALL LETTER O WITH DOUBLE ACUTE 
OE LATIN CAPITAL LIGATURE OE
oe LATIN SMALL LIGATURE OE
R' LATIN CAPITAL LETTER R WITH ACUTE
r' LATIN SMALL LETTER R WITH ACUTE
R, LATIN CAPITAL LETTER R WITH CEDILLA
r, LATIN SMALL LETTER R WITH CEDILLA
R< LATIN CAPITAL LETTER R WITH CARON
r< LATIN SMALL LETTER R WITH CARON
S' LATIN CAPITAL LETTER S WITH ACUTE
s' LATIN SMALL LETTER S WITH ACUTE
S> LATIN CAPITAL LETTER S WITH CIRCUMFLEX
s> LATIN SMALL LETTER S WITH CIRCUMFLEX
S, LATIN CAPITAL LETTER S WITH CEDILLA
s, LATIN SMALL LETTER S WITH CEDILLA
S< LATIN CAPITAL LETTER S WITH CARON
s< LATIN SMALL LETTER S WITH CARON
T, LATIN CAPITAL LETTER T WITH CEDILLA
t, LATIN SMALL LETTER T WITH CEDILLA
T< LATIN CAPITAL LETTER T WITH CARON
t< LATIN SMALL LETTER T WITH CARON
T/ LATIN CAPITAL LETTER T WITH STROKE
t/ LATIN SMALL LETTER T WITH STROKE
U? LATIN CAPITAL LETTER U WITH TILDE
u? LATIN SMALL LETTER U WITH TILDE
U- LATIN CAPITAL LETTER U WITH MACRON
u- LATIN SMALL LETTER U WITH MACRON
U( LATIN CAPITAL LETTER U WITH BREVE
u( LATIN SMALL LETTER U WITH BREVE
U0 LATIN CAPITAL LETTER U WITH RING ABOVE
u0 LATIN SMALL LETTER U WITH RING ABOVE
U" LATIN CAPITAL LETTER U WITH DOUBLE ACUTE 
u" LATIN SMALL LETTER U WITH DOUBLE ACUTE 
U; LATIN CAPITAL LETTER U WITH OGONEK
u; LATIN SMALL LETTER U WITH OGONEK
W> LATIN CAPITAL LETTER W WITH CIRCUMFLEX
w> LATIN SMALL LETTER W WITH CIRCUMFLEX
Y> LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
y> LATIN SMALL LETTER Y WITH CIRCUMFLEX
Y: LATIN CAPITAL LETTER Y WITH DIAERESIS
Z' LATIN CAPITAL LETTER Z WITH ACUTE
z' LATIN SMALL LETTER Z WITH ACUTE
Z. LATIN CAPITAL LETTER Z WITH DOT ABOVE
z. LATIN SMALL LETTER Z WITH DOT ABOVE
Z< LATIN CAPITAL LETTER Z WITH CARON
z< LATIN SMALL LETTER Z WITH CARON
   cell 128
   cell 160
O9 LATIN CAPITAL LETTER O WITH HORN
o9 LATIN SMALL LETTER O WITH HORN
OI LATIN CAPITAL LETTER OI
oi LATIN SMALL LETTER OI
   cell 166
yr LATIN LETTER YR
   cell 175
U9 LATIN CAPITAL LETTER U WITH HORN
u9 LATIN SMALL LETTER U WITH HORN
   cell 179
   LATIN CAPITAL LETTER Y WITH HOOK
   LATIN SMALL LETTER Y WITH HOOK
   cell 181
Z/ LATIN CAPITAL LETTER Z WITH STROKE
z/ LATIN SMALL LETTER Z WITH STROKE
ED LATIN CAPITAL LETTER EZH
   LATIN CAPITAL LETTER DZ WITH CARON
   LATIN CAPITAL LETTER D WITH SMALL LETTER Z WITH CARON
   LATIN SMALL LETTER DZ WITH CARON
   LATIN CAPITAL LETTER LJ
   LATIN CAPITAL LETTER L WITH SMALL LETTER J
   LATIN SMALL LETTER LJ
   LATIN CAPITAL LETTER NJ
   LATIN CAPITAL LETTER N WITH SMALL LETTER J
   LATIN SMALL LETTER NJ
   cell 205
A< LATIN CAPITAL LETTER A WITH CARON
a< LATIN SMALL LETTER A WITH CARON
I< LATIN CAPITAL LETTER I WITH CARON
i< LATIN SMALL LETTER I WITH CARON
O< LATIN CAPITAL LETTER O WITH CARON
o< LATIN SMALL LETTER O WITH CARON
U< LATIN CAPITAL LETTER U WITH CARON
u< LATIN SMALL LETTER U WITH CARON
U:- LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
u:- LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
U:' LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
u:' LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
U:< LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
u:< LATIN SMALL LETTER U WITH DIAERESIS AND CARON
U:! LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
u:! LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
   LATIN SMALL LETTER TURNED E
   cell 222
A1 LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
a1 LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
A7 LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON
a7 LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON
A3 LATIN CAPITAL LETTER AE WITH MACRON
a3 LATIN SMALL LETTER AE WITH MACRON
G/ LATIN CAPITAL LETTER G WITH STROKE
g/ LATIN SMALL LETTER G WITH STROKE
G< LATIN CAPITAL LETTER G WITH CARON
g< LATIN SMALL LETTER G WITH CARON
K< LATIN CAPITAL LETTER K WITH CARON
k< LATIN SMALL LETTER K WITH CARON
O; LATIN CAPITAL LETTER O WITH OGONEK
o; LATIN SMALL LETTER O WITH OGONEK
O1 LATIN CAPITAL LETTER O WITH OGONEK AND MACRON
o1 LATIN SMALL LETTER O WITH OGONEK AND MACRON
EZ LATIN CAPITAL LETTER EZH WITH CARON
ez LATIN SMALL LETTER EZH WITH CARON
j< LATIN SMALL LETTER J WITH CARON
   LATIN CAPITAL LETTER DZ
   LATIN CAPITAL LETTER D WITH SMALL LETTER Z
   LATIN SMALL LETTER DZ
   cell 244
G' LATIN CAPITAL LETTER G WITH ACUTE
g' LATIN SMALL LETTER G WITH ACUTE
   cell 250
AA' LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
aa' LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
AE' LATIN CAPITAL LETTER AE WITH ACUTE
ae' LATIN SMALL LETTER AE WITH ACUTE
O/' LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
o/' LATIN SMALL LETTER O WITH STROKE AND ACUTE

   row 002
   ....
   cell 191
;S MODIFIER LETTER LEFT HALF RING
   cell 199
'< CARON
   ....
   cell 216
'( BREVE
'. DOT ABOVE
'0 RING ABOVE
'; OGONEK
   SMALL TILDE
   cell 221
'" DOUBLE ACUTE ACCENT

   row 003
   cell 000
   COMBINING GRAVE ACCENT 
   COMBINING ACUTE ACCENT 
   COMBINING CIRCUMFLEX ACCENT 
   COMBINING TILDE 
   COMBINING MACRON 
   COMBINING OVERLINE
   cell 006
   COMBINING BREVE
   COMBINING DOT ABOVE 
   COMBINING DIAERESIS 
   COMBINING HOOK ABOVE
   COMBINING RING ABOVE 
   COMBINING DOUBLE ACCUTE ACCENT 
   COMBINING CARON 
   cell 039
   COMBINING CEDILLA 
   COMBINING OGONEK 
   cell 050
   COMBINING LOW LINE 
   COMBINING DOUBLE LOW LINE 
   cell 056
   COMBINING LONG SOLIDUS OVERLAY

   cell 112
   GREEK COMBINING IOTA BELOW
   GREEK COMBINING DASIA PNEUMATA
   GREEK COMBINING PSILI PNEUMATA
   cell 132
   GREEK COMBINING TONOS
   GREEK COMBINING DIAERESIS TONOS
   cell 134
A% GREEK CAPITAL LETTER ALPHA WITH ACUTE
   cell 136
E% GREEK CAPITAL LETTER EPSILON WITH ACUTE
Y% GREEK CAPITAL LETTER ETA WITH ACUTE
I% GREEK CAPITAL LETTER IOTA WITH ACUTE
   cell 140
O% GREEK CAPITAL LETTER OMICRON WITH ACUTE
   cell 142
U% GREEK CAPITAL LETTER UPSILON WITH ACUTE
W% GREEK CAPITAL LETTER OMEGA WITH ACUTE
i3 GREEK SMALL LETTER IOTA WITH ACUTE AND DIAERESIS
A* GREEK CAPITAL LETTER ALPHA
B* GREEK CAPITAL LETTER BETA
G* GREEK CAPITAL LETTER GAMMA
D* GREEK CAPITAL LETTER DELTA
E* GREEK CAPITAL LETTER EPSILON
Z* GREEK CAPITAL LETTER ZETA
Y* GREEK CAPITAL LETTER ETA
H* GREEK CAPITAL LETTER THETA
I* GREEK CAPITAL LETTER IOTA
K* GREEK CAPITAL LETTER KAPPA
L* GREEK CAPITAL LETTER LAMDA
M* GREEK CAPITAL LETTER MU
N* GREEK CAPITAL LETTER NU
C* GREEK CAPITAL LETTER XI
O* GREEK CAPITAL LETTER OMICRON
P* GREEK CAPITAL LETTER PI
R* GREEK CAPITAL LETTER RHO
   cell 163
S* GREEK CAPITAL LETTER SIGMA
T* GREEK CAPITAL LETTER TAU
U* GREEK CAPITAL LETTER UPSILON
F* GREEK CAPITAL LETTER PHI
X* GREEK CAPITAL LETTER CHI
Q* GREEK CAPITAL LETTER PSI
W* GREEK CAPITAL LETTER OMEGA
J* GREEK CAPITAL LETTER IOTA WITH DIAERESIS
V* GREEK CAPITAL LETTER UPSILON WITH DIAERESIS
a% GREEK SMALL LETTER ALPHA WITH ACUTE
e% GREEK SMALL LETTER EPSILON WITH ACUTE
y% GREEK SMALL LETTER ETA WITH ACUTE
i% GREEK SMALL LETTER IOTA WITH ACUTE
u3 GREEK SMALL LETTER UPSILON WITH ACUTE AND DIAERESIS
a* GREEK SMALL LETTER ALPHA
b* GREEK SMALL LETTER BETA
g* GREEK SMALL LETTER GAMMA
d* GREEK SMALL LETTER DELTA
e* GREEK SMALL LETTER EPSILON
z* GREEK SMALL LETTER ZETA
y* GREEK SMALL LETTER ETA
h* GREEK SMALL LETTER THETA
i* GREEK SMALL LETTER IOTA
k* GREEK SMALL LETTER KAPPA
l* GREEK SMALL LETTER LAMDA
m* GREEK SMALL LETTER MU
n* GREEK SMALL LETTER NU
c* GREEK SMALL LETTER XI
o* GREEK SMALL LETTER OMICRON
p* GREEK SMALL LETTER PI
r* GREEK SMALL LETTER RHO
*s GREEK SMALL LETTER FINAL SIGMA
s* GREEK SMALL LETTER SIGMA
t* GREEK SMALL LETTER TAU
u* GREEK SMALL LETTER UPSILON
f* GREEK SMALL LETTER PHI
x* GREEK SMALL LETTER CHI
q* GREEK SMALL LETTER PSI
w* GREEK SMALL LETTER OMEGA
j* GREEK SMALL LETTER IOTA WITH DIAERESIS
v* GREEK SMALL LETTER UPSILON WITH DIAERESIS
o% GREEK SMALL LETTER OMICRON WITH ACUTE
u% GREEK SMALL LETTER UPSILON WITH ACUTE
w% GREEK SMALL LETTER OMEGA WITH ACUTE
   ........
   cell 216
'G GREEK NUMERAL SIGN
,G GREEK LOWER NUMERAL SIGN
T3 GREEK CAPITAL LETTER STIGMA
t3 GREEK SMALL LETTER STIGMA
M3 GREEK CAPITAL LETTER DIGAMMA
m3 GREEK SMALL LETTER DIGAMMA
K3 GREEK CAPITAL LETTER KOPPA
k3 GREEK SMALL LETTER KOPPA
P3 GREEK CAPITAL LETTER SAMPI
p3 GREEK SMALL LETTER SAMPI
   ...
   cell 244
'% ACUTE ACCENT AND DIAERESIS (Tonos and Dialytika)
j3 GREEK IOTA BELOW

   row 004
   cell 001
IO CYRILLIC CAPITAL LETTER IO
D% CYRILLIC CAPITAL LETTER DJE (Serbocroatian)
G% CYRILLIC CAPITAL LETTER GJE (Macedonian)
IE CYRILLIC CAPITAL LETTER UKRAINIAN IE
DS CYRILLIC CAPITAL LETTER DZE (Macedonian)
II CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I
YI CYRILLIC CAPITAL LETTER YI (Ukrainian)
J% CYRILLIC CAPITAL LETTER JE
LJ CYRILLIC CAPITAL LETTER LJE
NJ CYRILLIC CAPITAL LETTER NJE
Ts CYRILLIC CAPITAL LETTER TSHE (Serbocroatian)
KJ CYRILLIC CAPITAL LETTER KJE (Macedonian)
   cell 014
V% CYRILLIC CAPITAL LETTER SHORT U (Byelorussian)
DZ CYRILLIC CAPITAL LETTER DZHE
A= CYRILLIC CAPITAL LETTER A
B= CYRILLIC CAPITAL LETTER BE
V= CYRILLIC CAPITAL LETTER VE
G= CYRILLIC CAPITAL LETTER GHE
D= CYRILLIC CAPITAL LETTER DE
E= CYRILLIC CAPITAL LETTER IE
Z% CYRILLIC CAPITAL LETTER ZHE
Z= CYRILLIC CAPITAL LETTER ZE
I= CYRILLIC CAPITAL LETTER I
J= CYRILLIC CAPITAL LETTER SHORT I
K= CYRILLIC CAPITAL LETTER KA
L= CYRILLIC CAPITAL LETTER EL
M= CYRILLIC CAPITAL LETTER EM
N= CYRILLIC CAPITAL LETTER EN
O= CYRILLIC CAPITAL LETTER O
P= CYRILLIC CAPITAL LETTER PE
R= CYRILLIC CAPITAL LETTER ER
S= CYRILLIC CAPITAL LETTER ES
T= CYRILLIC CAPITAL LETTER TE
U= CYRILLIC CAPITAL LETTER U
F= CYRILLIC CAPITAL LETTER EF
H= CYRILLIC CAPITAL LETTER HA
C= CYRILLIC CAPITAL LETTER TSE
C% CYRILLIC CAPITAL LETTER CHE
S% CYRILLIC CAPITAL LETTER SHA
Sc CYRILLIC CAPITAL LETTER SHCHA
=" CYRILLIC CAPITAL LETTER HARD SIGN
Y= CYRILLIC CAPITAL LETTER YERU
%" CYRILLIC CAPITAL LETTER SOFT SIGN
JE CYRILLIC CAPITAL LETTER E
JU CYRILLIC CAPITAL LETTER YU
JA CYRILLIC CAPITAL LETTER YA
a= CYRILLIC SMALL LETTER A
b= CYRILLIC SMALL LETTER BE
v= CYRILLIC SMALL LETTER VE
g= CYRILLIC SMALL LETTER GHE
d= CYRILLIC SMALL LETTER DE
e= CYRILLIC SMALL LETTER IE
z% CYRILLIC SMALL LETTER ZHE
z= CYRILLIC SMALL LETTER ZE
i= CYRILLIC SMALL LETTER I
j= CYRILLIC SMALL LETTER SHORT I
k= CYRILLIC SMALL LETTER KA
l= CYRILLIC SMALL LETTER EL
m= CYRILLIC SMALL LETTER EM
n= CYRILLIC SMALL LETTER EN
o= CYRILLIC SMALL LETTER O
p= CYRILLIC SMALL LETTER PE
r= CYRILLIC SMALL LETTER ER
s= CYRILLIC SMALL LETTER ES
t= CYRILLIC SMALL LETTER TE
u= CYRILLIC SMALL LETTER U
f= CYRILLIC SMALL LETTER EF
h= CYRILLIC SMALL LETTER HA
c= CYRILLIC SMALL LETTER TSE
c% CYRILLIC SMALL LETTER CHE
s% CYRILLIC SMALL LETTER SHA
sc CYRILLIC SMALL LETTER SHCHA
=' CYRILLIC SMALL LETTER HARD SIGN
y= CYRILLIC SMALL LETTER YERU
%' CYRILLIC SMALL LETTER SOFT SIGN
je CYRILLIC SMALL LETTER E
ju CYRILLIC SMALL LETTER YU
ja CYRILLIC SMALL LETTER YA
   cell 081
io CYRILLIC SMALL LETTER IO
d% CYRILLIC SMALL LETTER DJE (Serbocroatian)
g% CYRILLIC SMALL LETTER GJE (Macedonian)
ie CYRILLIC SMALL LETTER UKRAINIAN IE
ds CYRILLIC SMALL LETTER DZE (Macedonian)
ii CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I
yi CYRILLIC SMALL LETTER YI (Ukrainian)
j% CYRILLIC SMALL LETTER JE
lj CYRILLIC SMALL LETTER LJE
nj CYRILLIC SMALL LETTER NJE
ts CYRILLIC SMALL LETTER TSHE (Serbocroatian)
kj CYRILLIC SMALL LETTER KJE (Macedonian)
   cell 094
v% CYRILLIC SMALL LETTER SHORT U (Byelorussian)
dz CYRILLIC SMALL LETTER DZHE
   CYRILLIC CAPITAL LETTER OMEGA
   CYRILLIC SMALL LETTER OMEGA
   cell 098
Y3 CYRILLIC CAPITAL LETTER YAT
y3 CYRILLIC SMALL LETTER YAT
   cell 106
O3 CYRILLIC CAPITAL LETTER BIG YUS
o3 CYRILLIC SMALL LETTER BIG YUS
   cell 114
F3 CYRILLIC CAPITAL LETTER FITA
f3 CYRILLIC SMALL LETTER FITA
V3 CYRILLIC CAPITAL LETTER IZHITSA
v3 CYRILLIC SMALL LETTER IZHITSA

   ....
   cell 128
C3 CYRILLIC CAPITAL LETTER KOPPA
c3 CYRILLIC SMALL LETTER KOPPA
   cell 144
G3 CYRILLIC CAPITAL LETTER GHE WITH UPTURN
g3 CYRILLIC SMALL LETTER GHE WITH UPTURN

   row 005
   cell 208
A+ HEBREW LETTER ALEF
B+ HEBREW LETTER BET
G+ HEBREW LETTER GIMEL
D+ HEBREW LETTER DALET
H+ HEBREW LETTER HE
W+ HEBREW LETTER VAV
Z+ HEBREW LETTER ZAYIN
X+ HEBREW LETTER HET
Tj HEBREW LETTER TET
J+ HEBREW LETTER YOD
K% HEBREW LETTER FINAL KAF
K+ HEBREW LETTER KAF
L+ HEBREW LETTER LAMED
M% HEBREW LETTER FINAL MEM
M+ HEBREW LETTER MEM
N% HEBREW LETTER FINAL NUN
N+ HEBREW LETTER NUN
S+ HEBREW LETTER SAMEKH
E+ HEBREW LETTER AYIN
P% HEBREW LETTER FINAL PE
P+ HEBREW LETTER PE
Zj HEBREW LETTER FINAL TSADI
ZJ HEBREW LETTER TSADI
Q+ HEBREW LETTER QOF
R+ HEBREW LETTER RESH
Sh HEBREW LETTER SHIN
T+ HEBREW LETTER TAV
   .....

   row 006
   cell 012
,+ ARABIC COMMA
   cell 027
;+ ARABIC SEMICOLON
   cell 031
?+ ARABIC QUESTION MARK
   cell 033
H' ARABIC LETTER HAMZA
aM ARABIC LETTER ALEF WITH MADDA ABOVE
aH ARABIC LETTER ALEF WITH HAMZA ABOVE
wH ARABIC LETTER WAW WITH HAMZA ABOVE
ah ARABIC LETTER ALEF WITH HAMZA BELOW
yH ARABIC LETTER YEH WITH HAMZA ABOVE
a+ ARABIC LETTER ALEF
b+ ARABIC LETTER BEH
tm ARABIC LETTER TEH MARBUTA
t+ ARABIC LETTER TEH
tk ARABIC LETTER THEH
g+ ARABIC LETTER JEEM
hk ARABIC LETTER HAH
x+ ARABIC LETTER KHAH
d+ ARABIC LETTER DAL
dk ARABIC LETTER THAL
r+ ARABIC LETTER REH
z+ ARABIC LETTER ZAIN
s+ ARABIC LETTER SEEN
sn ARABIC LETTER SHEEN
c+ ARABIC LETTER SAD
dd ARABIC LETTER DAD
tj ARABIC LETTER TAH
zH ARABIC LETTER ZAH
e+ ARABIC LETTER AIN
i+ ARABIC LETTER GHAIN
   cell 064
++ ARABIC TATWEEL
f+ ARABIC LETTER FEH
q+ ARABIC LETTER QAF
k+ ARABIC LETTER KAF
l+ ARABIC LETTER LAM
m+ ARABIC LETTER MEEM
n+ ARABIC LETTER NOON
h+ ARABIC LETTER HEH
w+ ARABIC LETTER WAW
j+ ARABIC LETTER ALEF MAKSURA
y+ ARABIC LETTER YEH
:+ ARABIC FATHATAN
"+ ARABIC DAMMATAN
=+ ARABIC KASRATAN
/+ ARABIC FATHA
'+ ARABIC DAMMA
1+ ARABIC KASRA
3+ ARABIC SHADDA
0+ ARABIC SUKUN
   ....
   cell 112
aS SUPERSCRIPT ARABIC LETTER ALEF
   cell 126
p+ ARABIC LETTER PEH
   cell 164
v+ ARABIC LETTER VEH
   .....
   cell 175
gf ARABIC LETTER GAF
   cell 240
0a EASTERN ARABIC-INDIC DIGIT ZERO
1a EASTERN ARABIC-INDIC DIGIT ONE
2a EASTERN ARABIC-INDIC DIGIT TWO
3a EASTERN ARABIC-INDIC DIGIT THREE
4a EASTERN ARABIC-INDIC DIGIT FOUR
5a EASTERN ARABIC-INDIC DIGIT FIVE
6a EASTERN ARABIC-INDIC DIGIT SIX
7a EASTERN ARABIC-INDIC DIGIT SEVEN
8a EASTERN ARABIC-INDIC DIGIT EIGHT
9a EASTERN ARABIC-INDIC DIGIT NINE
   
   row 030
   cell 000
A-0 LATIN CAPITAL LETTER A WITH RING BELOW
a-0 LATIN SMALL LETTER A WITH RING BELOW
B. LATIN CAPITAL LETTER B WITH DOT ABOVE
b. LATIN SMALL LETTER B WITH DOT ABOVE
B-. LATIN CAPITAL LETTER B WITH DOT BELOW
b-. LATIN SMALL LETTER B WITH DOT BELOW
B_ LATIN CAPITAL LETTER B WITH LINE BELOW
b_ LATIN SMALL LETTER B WITH LINE BELOW
C,' LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE
c,' LATIN SMALL LETTER C WITH CEDILLA AND ACUTE
D. LATIN CAPITAL LETTER D WITH DOT ABOVE
d. LATIN SMALL LETTER D WITH DOT ABOVE
D-. LATIN CAPITAL LETTER D WITH DOT BELOW
d-. LATIN SMALL LETTER D WITH DOT BELOW
D_ LATIN CAPITAL LETTER D WITH LINE BELOW
d_ LATIN SMALL LETTER D WITH LINE BELOW
D, LATIN CAPITAL LETTER D WITH CEDILLA
d, LATIN SMALL LETTER D WITH CEDILLA
D-> LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW
d-> LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW
E-! LATIN CAPITAL LETTER E WITH MACRON AND GRAVE
e-! LATIN SMALL LETTER E WITH MACRON AND GRAVE
E-' LATIN CAPITAL LETTER E WITH MACRON AND ACUTE
e-' LATIN SMALL LETTER E WITH MACRON AND ACUTE
E-> LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW
e-> LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW
E-? LATIN CAPITAL LETTER E WITH TILDE BELOW
e-? LATIN SMALL LETTER E WITH TILDE BELOW
E,( LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE
e,( LATIN SMALL LETTER E WITH CEDILLA AND BREVE
F. LATIN CAPITAL LETTER F WITH DOT ABOVE
f. LATIN SMALL LETTER F WITH DOT ABOVE
G- LATIN CAPITAL LETTER G WITH MACRON
g- LATIN SMALL LETTER G WITH MACRON
H. LATIN CAPITAL LETTER H WITH DOT ABOVE
h. LATIN SMALL LETTER H WITH DOT ABOVE
H-. LATIN CAPITAL LETTER H WITH DOT BELOW
h-. LATIN SMALL LETTER H WITH DOT BELOW
H: LATIN CAPITAL LETTER H WITH DIAERESIS
h: LATIN SMALL LETTER H WITH DIAERESIS
H, LATIN CAPITAL LETTER H WITH CEDILLA
h, LATIN SMALL LETTER H WITH CEDILLA
H-( LATIN CAPITAL LETTER H WITH BREVE BELOW
h-( LATIN SMALL LETTER H WITH BREVE BELOW
I-? LATIN CAPITAL LETTER I WITH TILDE BELOW
i-? LATIN SMALL LETTER I WITH TILDE BELOW
I:' LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE
i:' LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE
K' LATIN CAPITAL LETTER K WITH ACUTE
k' LATIN SMALL LETTER K WITH ACUTE
K-. LATIN CAPITAL LETTER K WITH DOT BELOW
k-. LATIN SMALL LETTER K WITH DOT BELOW
K_ LATIN CAPITAL LETTER K WITH LINE BELOW
k_ LATIN SMALL LETTER K WITH LINE BELOW
L-. LATIN CAPITAL LETTER L WITH DOT BELOW
l-. LATIN SMALL LETTER L WITH DOT BELOW
L--. LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON
l--. LATIN SMALL LETTER L WITH DOT BELOW AND MACRON
L_ LATIN CAPITAL LETTER L WITH LINE BELOW
l_ LATIN SMALL LETTER L WITH LINE BELOW
L-> LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW
l-> LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW
M' LATIN CAPITAL LETTER M WITH ACUTE
m' LATIN SMALL LETTER M WITH ACUTE
M. LATIN CAPITAL LETTER M WITH DOT ABOVE
m. LATIN SMALL LETTER M WITH DOT ABOVE
M-. LATIN CAPITAL LETTER M WITH DOT BELOW
m-. LATIN SMALL LETTER M WITH DOT BELOW
N. LATIN CAPITAL LETTER N WITH DOT ABOVE
n. LATIN SMALL LETTER N WITH DOT ABOVE
N-. LATIN CAPITAL LETTER N WITH DOT BELOW
n-. LATIN SMALL LETTER N WITH DOT BELOW
N_ LATIN CAPITAL LETTER N WITH LINE BELOW
n_ LATIN SMALL LETTER N WITH LINE BELOW
N-> LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW
n-> LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW
O?' LATIN CAPITAL LETTER O WITH TILDE AND ACUTE
o?' LATIN SMALL LETTER O WITH TILDE AND ACUTE
O?: LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS
o?: LATIN SMALL LETTER O WITH TILDE AND DIAERESIS
O-! LATIN CAPITAL LETTER O WITH MACRON AND GRAVE
o-! LATIN SMALL LETTER O WITH MACRON AND GRAVE
O-' LATIN CAPITAL LETTER O WITH MACRON AND ACUTE
o-' LATIN SMALL LETTER O WITH MACRON AND ACUTE
P' LATIN CAPITAL LETTER P WITH ACUTE
p' LATIN SMALL LETTER P WITH ACUTE
P. LATIN CAPITAL LETTER P WITH DOT ABOVE
p. LATIN SMALL LETTER P WITH DOT ABOVE
R. LATIN CAPITAL LETTER R WITH DOT ABOVE
r. LATIN SMALL LETTER R WITH DOT ABOVE
R-. LATIN CAPITAL LETTER R WITH DOT BELOW
r-. LATIN SMALL LETTER R WITH DOT BELOW
R--. LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON
r--. LATIN SMALL LETTER R WITH DOT BELOW AND MACRON
R_ LATIN CAPITAL LETTER R WITH LINE BELOW
r_ LATIN SMALL LETTER R WITH LINE BELOW
S. LATIN CAPITAL LETTER S WITH DOT ABOVE
s. LATIN SMALL LETTER S WITH DOT ABOVE
S-. LATIN CAPITAL LETTER S WITH DOT BELOW
s-. LATIN SMALL LETTER S WITH DOT BELOW
S'. LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE
s'. LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE
S<. LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE
s<. LATIN SMALL LETTER S WITH CARON AND DOT ABOVE
S.-. LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE
s.-. LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE
T. LATIN CAPITAL LETTER T WITH DOT ABOVE
t. LATIN SMALL LETTER T WITH DOT ABOVE
T-. LATIN CAPITAL LETTER T WITH DOT BELOW
t-. LATIN SMALL LETTER T WITH DOT BELOW
T_ LATIN CAPITAL LETTER T WITH LINE BELOW
t_ LATIN SMALL LETTER T WITH LINE BELOW
T-> LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW
t-> LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW
U--: LATIN CAPITAL LETTER U WITH DIAERESIS BELOW
u--: LATIN SMALL LETTER U WITH DIAERESIS BELOW
U-? LATIN CAPITAL LETTER U WITH TILDE BELOW
u-? LATIN SMALL LETTER U WITH TILDE BELOW
U-> LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW
u-> LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW
U?' LATIN CAPITAL LETTER U WITH TILDE AND ACUTE
u?' LATIN SMALL LETTER U WITH TILDE AND ACUTE
U-: LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS
u-: LATIN SMALL LETTER U WITH MACRON AND DIAERESIS
V? LATIN CAPITAL LETTER V WITH TILDE
v? LATIN SMALL LETTER V WITH TILDE
V-. LATIN CAPITAL LETTER V WITH DOT BELOW
v-. LATIN SMALL LETTER V WITH DOT BELOW
W! LATIN CAPITAL LETTER W WITH GRAVE
w! LATIN SMALL LETTER W WITH GRAVE
W' LATIN CAPITAL LETTER W WITH ACUTE
w' LATIN SMALL LETTER W WITH ACUTE
W: LATIN CAPITAL LETTER W WITH DIAERESIS
w: LATIN SMALL LETTER W WITH DIAERESIS
W. LATIN CAPITAL LETTER W WITH DOT ABOVE
w. LATIN SMALL LETTER W WITH DOT ABOVE
W-. LATIN CAPITAL LETTER W WITH DOT BELOW
w-. LATIN SMALL LETTER W WITH DOT BELOW
X. LATIN CAPITAL LETTER X WITH DOT ABOVE
x. LATIN SMALL LETTER X WITH DOT ABOVE
X: LATIN CAPITAL LETTER X WITH DIAERESIS
x: LATIN SMALL LETTER X WITH DIAERESIS
Y. LATIN CAPITAL LETTER Y WITH DOT ABOVE
y. LATIN SMALL LETTER Y WITH DOT ABOVE
Z> LATIN CAPITAL LETTER Z WITH CIRCUMFLEX
z> LATIN SMALL LETTER Z WITH CIRCUMFLEX
Z-. LATIN CAPITAL LETTER Z WITH DOT BELOW
z-. LATIN SMALL LETTER Z WITH DOT BELOW
Z_ LATIN CAPITAL LETTER Z WITH LINE BELOW
z_ LATIN SMALL LETTER Z WITH LINE BELOW
h_ LATIN SMALL LETTER H WITH LINE BELOW
t: LATIN SMALL LETTER T WITH DIAERESIS
w0 LATIN SMALL LETTER W WITH RING ABOVE
y0 LATIN SMALL LETTER Y WITH RING ABOVE
   LATIN SMALL LETTER A WITH RIGHT HALF RING
   cell 160
A-. LATIN CAPITAL LETTER A WITH DOT BELOW
a-. LATIN SMALL LETTER A WITH DOT BELOW
A2 LATIN CAPITAL LETTER A WITH HOOK ABOVE
a2 LATIN SMALL LETTER A WITH HOOK ABOVE
A>' LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE
a>' LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE
A>! LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE
a>! LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE
A>2 LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
a>2 LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
A>? LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE
a>? LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE
A>-. LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW
a>-. LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW
A(' LATIN CAPITAL LETTER A WITH BREVE AND ACUTE
a(' LATIN SMALL LETTER A WITH BREVE AND ACUTE
A(! LATIN CAPITAL LETTER A WITH BREVE AND GRAVE
a(! LATIN SMALL LETTER A WITH BREVE AND GRAVE
A(2 LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE
a(2 LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE
A(? LATIN CAPITAL LETTER A WITH BREVE AND TILDE
a(? LATIN SMALL LETTER A WITH BREVE AND TILDE
A(-. LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW
a(-. LATIN SMALL LETTER A WITH BREVE AND DOT BELOW
E-. LATIN CAPITAL LETTER E WITH DOT BELOW
e-. LATIN SMALL LETTER E WITH DOT BELOW
E2 LATIN CAPITAL LETTER E WITH HOOK ABOVE
e2 LATIN SMALL LETTER E WITH HOOK ABOVE
E? LATIN CAPITAL LETTER E WITH TILDE
e? LATIN SMALL LETTER E WITH TILDE
E>' LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
e>' LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
E>! LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
e>! LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
E>2 LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
e>2 LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
E>? LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
e>? LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
E>-. LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
e>-. LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
I2 LATIN CAPITAL LETTER I WITH HOOK ABOVE
i2 LATIN SMALL LETTER I WITH HOOK ABOVE
I-. LATIN CAPITAL LETTER I WITH DOT BELOW
i-. LATIN SMALL LETTER I WITH DOT BELOW
O-. LATIN CAPITAL LETTER O WITH DOT BELOW
o-. LATIN SMALL LETTER O WITH DOT BELOW
O2 LATIN CAPITAL LETTER O WITH HOOK ABOVE
o2 LATIN SMALL LETTER O WITH HOOK ABOVE
O>' LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE
o>' LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE
O>! LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE
o>! LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE
O>2 LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
o>2 LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
O>? LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE
o>? LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE
O>-. LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
o>-. LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
O9' LATIN CAPITAL LETTER O WITH HORN AND ACUTE
o9' LATIN SMALL LETTER O WITH HORN AND ACUTE
O9! LATIN CAPITAL LETTER O WITH HORN AND GRAVE
o9! LATIN SMALL LETTER O WITH HORN AND GRAVE
O92 LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE
o92 LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE
O9? LATIN CAPITAL LETTER O WITH HORN AND TILDE
o9? LATIN SMALL LETTER O WITH HORN AND TILDE
O9-. LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW
o9-. LATIN SMALL LETTER O WITH HORN AND DOT BELOW
U-. LATIN CAPITAL LETTER U WITH DOT BELOW
u-. LATIN SMALL LETTER U WITH DOT BELOW
U2 LATIN CAPITAL LETTER U WITH HOOK ABOVE
u2 LATIN SMALL LETTER U WITH HOOK ABOVE
U9' LATIN CAPITAL LETTER U WITH HORN AND ACUTE
u9' LATIN SMALL LETTER U WITH HORN AND ACUTE
U9! LATIN CAPITAL LETTER U WITH HORN AND GRAVE
u9! LATIN SMALL LETTER U WITH HORN AND GRAVE
U92 LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE
u92 LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE
U9? LATIN CAPITAL LETTER U WITH HORN AND TILDE
u9? LATIN SMALL LETTER U WITH HORN AND TILDE
U9-. LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW
u9-. LATIN SMALL LETTER U WITH HORN AND DOT BELOW
Y! LATIN CAPITAL LETTER Y WITH GRAVE
y! LATIN SMALL LETTER Y WITH GRAVE
Y-. LATIN CAPITAL LETTER Y WITH DOT BELOW
y-. LATIN SMALL LETTER Y WITH DOT BELOW
Y2 LATIN CAPITAL LETTER Y WITH HOOK ABOVE
y2 LATIN SMALL LETTER Y WITH HOOK ABOVE
Y? LATIN CAPITAL LETTER Y WITH TILDE
y? LATIN SMALL LETTER Y WITH TILDE

   row 031
   cell 000
;' GREEK DASIA AND ACUTE ACCENT
,' GREEK PSILI AND ACUTE ACCENT
;! GREEK DASIA AND VARIA
,! GREEK PSILI AND VARIA
?; GREEK DASIA AND PERISPOMENI 
?, GREEK PSILI AND PERISPOMENI 
!: GREEK DIAERESIS AND VARIA
?: GREEK DIAERESIS AND PERISPOMENI

   row 032
   cell 002
1N EN SPACE
1M EM SPACE
3M THREE-PER-EM SPACE
4M FOUR-PER-EM SPACE
6M SIX-PER-EM SPACE

   cell 009
1T THIN SPACE
1H HAIR SPACE

   cell 016
-1 HYPHEN
   cell 019
-N EN DASH
-M EM DASH
-3 HORIZONTAL BAR
   cell 022
!2 DOUBLE VERTICAL LINE
=2 DOUBLE LOW LINE
'6 LEFT SINGLE QUOTATION MARK
'9 RIGHT SINGLE QUOTATION MARK
.9 SINGLE LOW-9 QUOTATION MARK
9' SINGLE HIGH-REVERSED-9 QUOTATION MARK
"6 LEFT DOUBLE QUOTATION MARK
"9 RIGHT DOUBLE QUOTATION MARK
:9 DOUBLE LOW-9 QUOTATION MARK
9" DOUBLE HIGH-REVERSED-9 QUOTATION MARK
   cell 032
/- DAGGER
/= DOUBLE DAGGER
   cell 037
.. TWO DOT LEADER
   cell 048
%0 PER MILLE SIGN
   cell 050
1' PRIME
2' DOUBLE PRIME
3' TRIPLE PRIME
1" REVERSED PRIME
2" REVERSED DOUBLE PRIME
3" REVERSED TRIPLE PRIME
   cell 056
Ca CARET
<1 SINGLE LEFT-POINTING ANGLE QUOTATION MARK
>1 SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
:X REFERENCE MARK
!*2 DOUBLE EXCLAMATION MARK
   cell 062
'- OVERLINE
   cell 068
/f FRACTION SLASH

   cell 112
0S SUPERSCRIPT DIGIT ZERO 
   cell 116
4S SUPERSCRIPT DIGIT FOUR 
5S SUPERSCRIPT DIGIT FIVE 
6S SUPERSCRIPT DIGIT SIX 
7S SUPERSCRIPT DIGIT SEVEN 
8S SUPERSCRIPT DIGIT EIGHT 
9S SUPERSCRIPT DIGIT NINE 
+S SUPERSCRIPT PLUS SIGN
-S SUPERSCRIPT MINUS 
=S SUPERSCRIPT EQUALS SIGN
(S SUPERSCRIPT LEFT PARENTHESIS
)S SUPERSCRIPT RIGHT PARENTHESIS
nS SUPERSCRIPT LATIN SMALL LETTER N
0s SUBSCRIPT DIGIT ZERO 
1s SUBSCRIPT DIGIT ONE 
2s SUBSCRIPT DIGIT TWO 
3s SUBSCRIPT DIGIT THREE 
4s SUBSCRIPT DIGIT FOUR 
5s SUBSCRIPT DIGIT FIVE 
6s SUBSCRIPT DIGIT SIX 
7s SUBSCRIPT DIGIT SEVEN 
8s SUBSCRIPT DIGIT EIGHT 
9s SUBSCRIPT DIGIT NINE 
+s SUBSCRIPT PLUS SIGN
-s SUBSCRIPT MINUS 
=s SUBSCRIPT EQUALS SIGN
(s SUBSCRIPT LEFT PARENTHESIS
)s SUBSCRIPT RIGHT PARENTHESIS
   cell 164
Li LIRA SIGN
   cell 167
Pt PESETA SIGN
   cell 169
W= WON SIGN

   row 033
   cell 003
oC DEGREE CENTIGRADE
   cell 005
co CARE OF
   cell 009
oF DEGREE FAHRENHEIT
   cell 022
N0 NUMERO SIGN
PO SOUND RECORDING COPYRIGHT
   cell 030
Rx PRESCRIPTION TAKE
   cell 032
SM SERVICE MARK
   TELEPHONE SIGN
   cell 034
TM TRADE MARK SIGN
   cell 038
Om OHM SIGN
   cell 043
AO ANGSTROEM SIGN

   cell 083
13 VULGAR FRACTION ONE THIRD
23 VULGAR FRACTION TWO THIRDS
15 VULGAR FRACTION ONE FIFTH
25 VULGAR FRACTION TWO FIFTHS
35 VULGAR FRACTION THREE FIFTHS
45 VULGAR FRACTION FOUR FIFTHS
16 VULGAR FRACTION ONE SIXTH
56 VULGAR FRACTION FIVE SIXTHS
18 VULGAR FRACTION ONE EIGHTH
38 VULGAR FRACTION THREE EIGHTHS
58 VULGAR FRACTION FIVE EIGHTHS
78 VULGAR FRACTION SEVEN EIGHTHS
   FRACTION NUMERATOR ONE
   cell 096
1R ROMAN NUMERAL ONE
2R ROMAN NUMERAL TWO
3R ROMAN NUMERAL THREE
4R ROMAN NUMERAL FOUR
5R ROMAN NUMERAL FIVE
6R ROMAN NUMERAL SIX
7R ROMAN NUMERAL SEVEN
8R ROMAN NUMERAL EIGHT
9R ROMAN NUMERAL NINE
aR ROMAN NUMERAL TEN
bR ROMAN NUMERAL ELEVEN
cR ROMAN NUMERAL TWELVE
50R ROMAN NUMERAL FIFTY
100R ROMAN NUMERAL ONE HUNDRED
500R ROMAN NUMERAL FIVE HUNDRED
1000R ROMAN NUMERAL ONE THOUSAND
1r SMALL ROMAN NUMERAL ONE
2r SMALL ROMAN NUMERAL TWO
3r SMALL ROMAN NUMERAL THREE
4r SMALL ROMAN NUMERAL FOUR
5r SMALL ROMAN NUMERAL FIVE
6r SMALL ROMAN NUMERAL SIX
7r SMALL ROMAN NUMERAL SEVEN
8r SMALL ROMAN NUMERAL EIGHT
9r SMALL ROMAN NUMERAL NINE
ar SMALL ROMAN NUMERAL TEN
br SMALL ROMAN NUMERAL ELEVEN
cr SMALL ROMAN NUMERAL TWELVE
50r SMALL ROMAN NUMERAL FIFTY
100r SMALL ROMAN NUMERAL ONE HUNDRED
500r SMALL ROMAN NUMERAL FIVE HUNDRED
1000r SMALL ROMAN NUMERAL ONE THOUSAND
1000RCD ROMAN NUMERAL ONE THOUSAND C D
5000R ROMAN NUMERAL FIVE THOUSAND
10000R ROMAN NUMERAL TEN THOUSAND
 
   row 033
   cell 144
<- LEFTWARDS ARROW
-! UPWARDS ARROW
-> RIGHTWARDS ARROW
-v DOWNWARDS ARROW
<> LEFT RIGHT ARROW
UD UP DOWN ARROW
<!! NORTH WEST ARROW
//> NORTH EAST ARROW
!!> SOUTH EAST ARROW
<// SOUTH WEST ARROW
   cell 208
<= LEFTWARDS DOUBLE ARROW
   cell 210
=> RIGHTWARDS DOUBLE ARROW
   cell 212
== LEFT RIGHT DOUBLE ARROW


   row 034
   cell 00
FA FOR ALL
   cell 002
dP PARTIAL DIFFERENTIAL
TE THERE EXISTS
   cell 005
/0 EMPTY SET
DE INCREMENT
NB NABLA
(- ELEMENT OF
   cell 011
-) CONTAINS AS MEMBER
   cell 015
*P N-ARY PRODUCT
   cell 017
+Z N-ARY SUMMATION
-2 MINUS SIGN
-+ MINUS-OR-PLUS SIGN
   cell 023
*- ASTERISK OPERATOR
Ob RING OPERATOR
Sb BULLET OPERATOR
RT SQUARE ROOT
   cell 029
0( PROPORTIONAL TO
00 INFINITY
-L RIGHT ANGLE
-V ANGLE
   cell 037
PP PARALLEL TO
   cell 039
AN LOGICAL AND
OR LOGICAL OR
(U INTERSECTION
)U UNION
In INTEGRAL
DI DOUBLE INTEGRAL
   cell 046
Io CONTOUR INTEGRAL
   cell 052
.: THEREFORE
:. BECAUSE
:R RATIO
:: PROPORTION 
   cell 060
?1 TILDE OPERATOR
   cell 062
CG INVERTED LAZY S
   cell 067
?- ASYMPTOTICALLY EQUAL TO
   cell 069
?= APPROXIMATELY EQUAL TO
   cell 072
?2 ALMOST EQUAL TO
   cell 076
=? ALL EQUAL TO
   cell 083
HI IMAGE OF OR APPROXIMATELY EQUAL TO
   cell 096
!= NOT EQUAL TO
=3 IDENTICAL TO
   cell 100
=< LESS-THAN OR EQUAL TO
>= GREATER-THAN OR EQUAL TO
   cell 106
<* MUCH LESS-THAN
*> MUCH GREATER-THAN
   cell 110
!< NOT LESS-THAN
!> NOT GREATER-THAN

   row 034
   cell 130
(C SUBSET OF
)C SUPERSET OF
   cell 134
(_ SUBSET OF OR EQUAL TO
)_ SUPERSET OF OR EQUAL TO
   cell 153
0. CIRCLED DOT OPERATOR
02 CIRCLED RING OPERATOR
   cell 165
-T UP TACK
   cell 197
.P DOT OPERATOR
   cell 238
:3 VERTICAL ELLIPSIS
.3 MIDLINE HORIZONTAL ELLIPSIS
 
   row 035
   cell 002
Eh HOUSE
   cell 008
<7 LEFT CEILING
>7 RIGHT CEILING
7< LEFT FLOOR
7> RIGHT FLOOR
   cell 016
NI REVERSED NOT SIGN
   cell 018
(A ARC
   cell 021
TR TELEPHONE RECORDER
   cell 032
Iu TOP HALF INTEGRAL
Il BOTTOM HALF INTEGRAL
   cell 041
</ LEFT-POINTING ANGLE BRACKET
/> RIGHT-POINTING ANGLE BRACKET
   
   row 036
   cell 035
Vs OPEN BOX
   cell 064
1h OCR HOOK
3h OCR CHAIR
2h OCR FORK
4h OCR INVERTED FORK
   cell 070
1j OCR BRANCH BANK IDENTIFICATION
2j OCR AMOUNT OF CHECK
3j OCR DASH
4j OCR CUSTOMER ACCOUNT NUMBER 

   cell 096
1-o CIRCLED DIGIT ONE
2-o CIRCLED DIGIT TWO
3-o CIRCLED DIGIT THREE
4-o CIRCLED DIGIT FOUR
5-o CIRCLED DIGIT FIVE
6-o CIRCLED DIGIT SIX
7-o CIRCLED DIGIT SEVEN
8-o CIRCLED DIGIT EIGHT
9-o CIRCLED DIGIT NINE
10-o CIRCLED NUMBER TEN
11-o CIRCLED NUMBER ELEVEN
12-o CIRCLED NUMBER TWELVE
13-o CIRCLED NUMBER THIRTEEN
14-o CIRCLED NUMBER FOURTEEN
15-o CIRCLED NUMBER FIFTEEN
16-o CIRCLED NUMBER SIXTEEN
17-o CIRCLED NUMBER SEVENTEEN
18-o CIRCLED NUMBER EIGHTEEN
19-o CIRCLED NUMBER NINETEEN
20-o CIRCLED NUMBER TWENTY
(1) PARENTHESIZED DIGIT ONE
(2) PARENTHESIZED DIGIT TWO
(3) PARENTHESIZED DIGIT THREE
(4) PARENTHESIZED DIGIT FOUR
(5) PARENTHESIZED DIGIT FIVE
(6) PARENTHESIZED DIGIT SIX
(7) PARENTHESIZED DIGIT SEVEN
(8) PARENTHESIZED DIGIT EIGHT
(9) PARENTHESIZED DIGIT NINE
(10) PARENTHESIZED NUMBER TEN
(11) PARENTHESIZED NUMBER ELEVEN
(12) PARENTHESIZED NUMBER TWELVE
(13) PARENTHESIZED NUMBER THIRTEEN
(14) PARENTHESIZED NUMBER FOURTEEN
(15) PARENTHESIZED NUMBER FIFTEEN
(16) PARENTHESIZED NUMBER SIXTEEN
(17) PARENTHESIZED NUMBER SEVENTEEN
(18) PARENTHESIZED NUMBER EIGHTEEN
(19) PARENTHESIZED NUMBER NINETEEN
(20) PARENTHESIZED NUMBER TWENTY
1. DIGIT ONE FULL STOP
2. DIGIT TWO FULL STOP
3. DIGIT THREE FULL STOP
4. DIGIT FOUR FULL STOP
5. DIGIT FIVE FULL STOP
6. DIGIT SIX FULL STOP
7. DIGIT SEVEN FULL STOP
8. DIGIT EIGHT FULL STOP
9. DIGIT NINE FULL STOP
10. NUMBER TEN FULL STOP
11. NUMBER ELEVEN FULL STOP
12. NUMBER TWELVE FULL STOP
13. NUMBER THIRTEEN FULL STOP
14. NUMBER FOURTEEN FULL STOP
15. NUMBER FIFTEEN FULL STOP
16. NUMBER SIXTEEN FULL STOP
17. NUMBER SEVENTEEN FULL STOP
18. NUMBER EIGHTEEN FULL STOP
19. NUMBER NINETEEN FULL STOP
20. NUMBER TWENTY FULL STOP
(a) PARENTHESIZED LATIN SMALL LETTER A
(b) PARENTHESIZED LATIN SMALL LETTER B
(c) PARENTHESIZED LATIN SMALL LETTER C
(d) PARENTHESIZED LATIN SMALL LETTER D
(e) PARENTHESIZED LATIN SMALL LETTER E
(f) PARENTHESIZED LATIN SMALL LETTER F
(g) PARENTHESIZED LATIN SMALL LETTER G
(h) PARENTHESIZED LATIN SMALL LETTER H
(i) PARENTHESIZED LATIN SMALL LETTER I
(j) PARENTHESIZED LATIN SMALL LETTER J
(k) PARENTHESIZED LATIN SMALL LETTER K
(l) PARENTHESIZED LATIN SMALL LETTER L
(m) PARENTHESIZED LATIN SMALL LETTER M
(n) PARENTHESIZED LATIN SMALL LETTER N
(o) PARENTHESIZED LATIN SMALL LETTER O
(p) PARENTHESIZED LATIN SMALL LETTER P
(q) PARENTHESIZED LATIN SMALL LETTER Q
(r) PARENTHESIZED LATIN SMALL LETTER R
(s) PARENTHESIZED LATIN SMALL LETTER S
(t) PARENTHESIZED LATIN SMALL LETTER T
(u) PARENTHESIZED LATIN SMALL LETTER U
(v) PARENTHESIZED LATIN SMALL LETTER V
(w) PARENTHESIZED LATIN SMALL LETTER W
(x) PARENTHESIZED LATIN SMALL LETTER X
(y) PARENTHESIZED LATIN SMALL LETTER Y
(z) PARENTHESIZED LATIN SMALL LETTER Z
A-o CIRCLED LATIN CAPITAL LETTER A
B-o CIRCLED LATIN CAPITAL LETTER B
C-o CIRCLED LATIN CAPITAL LETTER C
D-o CIRCLED LATIN CAPITAL LETTER D
E-o CIRCLED LATIN CAPITAL LETTER E
F-o CIRCLED LATIN CAPITAL LETTER F
G-o CIRCLED LATIN CAPITAL LETTER G
H-o CIRCLED LATIN CAPITAL LETTER H
I-o CIRCLED LATIN CAPITAL LETTER I
J-o CIRCLED LATIN CAPITAL LETTER J
K-o CIRCLED LATIN CAPITAL LETTER K
L-o CIRCLED LATIN CAPITAL LETTER L
M-o CIRCLED LATIN CAPITAL LETTER M
N-o CIRCLED LATIN CAPITAL LETTER N
O-o CIRCLED LATIN CAPITAL LETTER O
P-o CIRCLED LATIN CAPITAL LETTER P
Q-o CIRCLED LATIN CAPITAL LETTER Q
R-o CIRCLED LATIN CAPITAL LETTER R
S-o CIRCLED LATIN CAPITAL LETTER S
T-o CIRCLED LATIN CAPITAL LETTER T
U-o CIRCLED LATIN CAPITAL LETTER U
V-o CIRCLED LATIN CAPITAL LETTER V
W-o CIRCLED LATIN CAPITAL LETTER W
X-o CIRCLED LATIN CAPITAL LETTER X
Y-o CIRCLED LATIN CAPITAL LETTER Y
Z-o CIRCLED LATIN CAPITAL LETTER Z
a-o CIRCLED LATIN SMALL LETTER A
b-o CIRCLED LATIN SMALL LETTER B
c-o CIRCLED LATIN SMALL LETTER C
d-o CIRCLED LATIN SMALL LETTER D
e-o CIRCLED LATIN SMALL LETTER E
f-o CIRCLED LATIN SMALL LETTER F
g-o CIRCLED LATIN SMALL LETTER G
h-o CIRCLED LATIN SMALL LETTER H
i-o CIRCLED LATIN SMALL LETTER I
j-o CIRCLED LATIN SMALL LETTER J
k-o CIRCLED LATIN SMALL LETTER K
l-o CIRCLED LATIN SMALL LETTER L
m-o CIRCLED LATIN SMALL LETTER M
n-o CIRCLED LATIN SMALL LETTER N
o-o CIRCLED LATIN SMALL LETTER O
p-o CIRCLED LATIN SMALL LETTER P
q-o CIRCLED LATIN SMALL LETTER Q
r-o CIRCLED LATIN SMALL LETTER R
s-o CIRCLED LATIN SMALL LETTER S
t-o CIRCLED LATIN SMALL LETTER T
u-o CIRCLED LATIN SMALL LETTER U
v-o CIRCLED LATIN SMALL LETTER V
w-o CIRCLED LATIN SMALL LETTER W
x-o CIRCLED LATIN SMALL LETTER X
y-o CIRCLED LATIN SMALL LETTER Y
z-o CIRCLED LATIN SMALL LETTER Z
0-o CIRCLED DIGIT ZERO

   row 037
   cell 000
hh BOX DRAWINGS LIGHT HORIZONTAL
HH BOX DRAWINGS HEAVY HORIZONTAL
vv BOX DRAWINGS LIGHT VERTICAL
VV BOX DRAWINGS HEAVY VERTICAL
3- BOX DRAWINGS LIGHT TRIPLE DASH HORIZONTAL
3_ BOX DRAWINGS HEAVY TRIPLE DASH HORIZONTAL
3! BOX DRAWINGS LIGHT TRIPLE DASH VERTICAL
3/ BOX DRAWINGS HEAVY TRIPLE DASH VERTICAL
4- BOX DRAWINGS LIGHT QUADRUPLE DASH HORIZONTAL
4_ BOX DRAWINGS HEAVY QUADRUPLE DASH HORIZONTAL
4! BOX DRAWINGS LIGHT QUADRUPLE DASH VERTICAL
4/ BOX DRAWINGS HEAVY QUADRUPLE DASH VERTICAL
   naming: first vertical (up, down) - then horizontal (left, right)
dr BOX DRAWINGS LIGHT DOWN AND RIGHT
dR BOX DRAWINGS DOWN LIGHT AND RIGHT HEAVY
Dr BOX DRAWINGS DOWN HEAVY AND RIGHT LIGHT
DR BOX DRAWINGS HEAVY DOWN AND RIGHT
dl BOX DRAWINGS LIGHT DOWN AND LEFT
dL BOX DRAWINGS DOWN LIGHT AND LEFT HEAVY
Dl BOX DRAWINGS DOWN HEAVY AND LEFT LIGHT
LD BOX DRAWINGS HEAVY DOWN AND LEFT
ur BOX DRAWINGS LIGHT UP AND RIGHT
uR BOX DRAWINGS UP LIGHT AND RIGHT HEAVY
Ur BOX DRAWINGS UP HEAVY AND RIGHT LIGHT
UR BOX DRAWINGS HEAVY UP AND RIGHT
ul BOX DRAWINGS LIGHT UP AND LEFT
uL BOX DRAWINGS UP LIGHT AND LEFT HEAVY
Ul BOX DRAWINGS UP HEAVY AND LEFT LIGHT
UL BOX DRAWINGS HEAVY UP AND LEFT
vr BOX DRAWINGS LIGHT VERTICAL AND RIGHT
vR BOX DRAWINGS VERTICAL LIGHT AND RIGHT HEAVY
Udr BOX DRAWINGS UP HEAVY AND RIGHT DOWN LIGHT
uDr BOX DRAWINGS DOWN HEAVY AND RIGHT UP LIGHT
Vr BOX DRAWINGS VERTICAL HEAVY AND RIGHT LIGHT
UdR BOX DRAWINGS DOWN LIGHT AND RIGHT UP HEAVY
uDR BOX DRAWINGS UP LIGHT AND RIGHT DOWN HEAVY
VR BOX DRAWINGS HEAVY VERTICAL AND RIGHT
vl BOX DRAWINGS LIGHT VERTICAL AND LEFT
vL BOX DRAWINGS VERTICAL LIGHT AND LEFT HEAVY
Udl BOX DRAWINGS UP HEAVY AND LEFT DOWN LIGHT
uDl BOX DRAWINGS DOWN HEAVY AND LEFT UP LIGHT
Vl BOX DRAWINGS VERTICAL HEAVY AND LEFT LIGHT
UdL BOX DRAWINGS DOWN LIGHT AND LEFT UP HEAVY
uDL BOX DRAWINGS UP LIGHT AND LEFT DOWN HEAVY
VL BOX DRAWINGS HEAVY VERTICAL AND LEFT
dh BOX DRAWINGS LIGHT DOWN AND HORIZONTAL 
dLr BOX DRAWINGS LEFT HEAVY AND RIGHT DOWN LIGHT
dlR BOX DRAWINGS RIGHT HEAVY AND LEFT DOWN LIGHT
dH BOX DRAWINGS DOWN LIGHT AND HORIZONTAL HEAVY
Dh BOX DRAWINGS DOWN HEAVY AND HORIZONTAL LIGHT
DLr BOX DRAWINGS RIGHT LIGHT AND LEFT DOWN HEAVY
DlR BOX DRAWINGS LEFT LIGHT AND RIGHT DOWN HEAVY
DH BOX DRAWINGS HEAVY DOWN AND HORIZONTAL
uh BOX DRAWINGS LIGHT UP AND HORIZONTAL
uLr BOX DRAWINGS LEFT HEAVY AND RIGHT UP LIGHT
ulR BOX DRAWINGS RIGHT HEAVY AND LEFT UP LIGHT
uH BOX DRAWINGS UP LIGHT AND HORIZONTAL HEAVY
Uh BOX DRAWINGS UP HEAVY AND HORIZONTAL LIGHT
ULr BOX DRAWINGS RIGHT LIGHT AND LEFT UP HEAVY
UlR BOX DRAWINGS LEFT LIGHT AND RIGHT UP HEAVY
UH BOX DRAWINGS HEAVY UP AND HORIZONTAL
vh BOX DRAWINGS LIGHT VERTICAL AND HORIZONTAL
vLr BOX DRAWINGS LEFT HEAVY AND RIGHT VERTICAL LIGHT
vlR BOX DRAWINGS RIGHT HEAVY AND LEFT VERTICAL LIGHT
vH BOX DRAWINGS VERTICAL LIGHT AND HORIZONTAL HEAVY
Udh BOX DRAWINGS UP HEAVY AND DOWN HORIZONTAL LIGHT
uDh BOX DRAWINGS DOWN HEAVY AND UP HORIZONTAL LIGHT
Vh BOX DRAWINGS VERTICAL HEAVY AND HORIZONTAL LIGHT
UdLr BOX DRAWINGS LEFT UP HEAVY AND RIGHT DOWN LIGHT
UdlR BOX DRAWINGS RIGHT UP HEAVY AND LEFT DOWN LIGHT
uDLr BOX DRAWINGS LEFT DOWN HEAVY AND RIGHT UP LIGHT
uDlR BOX DRAWINGS RIGHT DOWN HEAVY AND LEFT UP LIGHT
UdH BOX DRAWINGS DOWN LIGHT AND UP HORIZONTAL HEAVY
uDH BOX DRAWINGS UP LIGHT AND DOWN HORIZONTAL HEAVY
VLr BOX DRAWINGS RIGHT LIGHT AND LEFT VERTICAL HEAVY
VlR BOX DRAWINGS LEFT LIGHT AND RIGHT VERTICAL HEAVY
VH BOX DRAWINGS HEAVY VERTICAL AND HORIZONTAL
   .....
   cell 113
FD BOX DRAWINGS LIGHT DIAGONAL UPPER RIGHT TO LOWER LEFT
BD BOX DRAWINGS LIGHT DIAGONAL UPPER LEFT TO LOWER RIGHT

   row 037
   cell 128
TB UPPER HALF BLOCK
   cell 132
LB LOWER HALF BLOCK
   cell 136
FB FULL BLOCK
   cell 140
lB LEFT HALF BLOCK
   cell 144
RB RIGHT HALF BLOCK
.S LIGHT SHADE
:S MEDIUM SHADE
?S DARK SHADE
   cell 160
fS BLACK SQUARE
OS WHITE SQUARE
RO WHITE SQUARE WITH ROUNDED CORNERS
Rr WHITE SQUARE CONTAINING BLACK SMALL SQUARE
RF SQUARE WITH HORIZONTAL FILL
RY SQUARE WITH VERTICAL FILL
RH SQUARE WITH ORTHOGONAL CROSSHATCH FILL
RZ SQUARE WITH UPPER LEFT TO LOWER RIGHT FILL
RK SQUARE WITH UPPER RIGHT TO LOWER LEFT FILL
RX SQUARE WITH DIAGONAL CROSSHATCH FILL
sB BLACK SMALL SQUARE
   cell 172
SR BLACK RECTANGLE
Or WHITE RECTANGLE
   cell 178
UT BLACK UP-POINTING TRIANGLE
uT WHITE UP-POINTING TRIANGLE
   cell 182
PR BLACK RIGHT-POINTING TRIANGLE
Tr WHITE RIGHT-POINTING TRIANGLE
   cell 188
Dt BLACK DOWN-POINTING TRIANGLE
dT WHITE DOWN-POINTING TRIANGLE 
   cell 192
PL BLACK LEFT-POINTING TRIANGLE
Tl WHITE LEFT-POINTING TRIANGLE
   cell 198
Db BLACK DIAMOND
Dw WHITE DIAMOND
   cell 202
LZ LOZENGE
0m WHITE CIRCLE
   cell 206
0o BULLSEYE
0M BLACK CIRCLE
0L CIRCLE WITH LEFT HALF BLACK
0R CIRCLE WITH RIGHT HALF BLACK
   cell 216
Sn INVERSE BULLET
Ic INVERSE WHITE CIRCLE
   cell 226
Fd BLACK LOWER RIGHT TRIANGLE
Bd BLACK LOWER LEFT TRIANGLE

   row 038
   cell 005
*2 BLACK STAR
*1 WHITE STAR
   cell 014
TEL BLACK TELEPHONE
tel WHITE TELEPHONE
   cell 028
<H WHITE LEFT POINTING INDEX
   cell 030
>H WHITE RIGHT POINTING INDEX
   cell 058
0u WHITE SMILING FACE
0U BLACK SMILING FACE
SU WHITE SUN WITH RAYS
   cell 064
Fm FEMALE SIGN
   cell 066
Ml MALE SIGN
   cell 096
cS BLACK SPADE SUIT
cH WHITE HEART SUIT
cD WHITE DIAMOND SUIT
cC BLACK CLUB SUIT
cS- WHITE SPADE SUIT
cH- BLACK HEART SUIT
cD- BLACK DIAMOND SUIT
cC- WHITE CLUB SUIT
   cell 105
Md QUARTER NOTE
M8 EIGHTH NOTE
M2 BARRED EIGHTH NOTES
M16 BARRED SIXTEENTH NOTES
   cell 109
Mb MUSIC FLAT SIGN
Mx MUSIC NATURAL SIGN
MX MUSIC SHARP SIGN

   row 039
   cell 019
OK CHECK MARK
   cell 023
XX BALLOT X
   cell 032
-X MALTESE CROSS

   row 048
   cell 000
IS IDEOGRAPHIC SPACE
,_ IDEOGRAPHIC COMMA
._ IDEOGRAPHIC PERIOD
+" DITTO MARK
+_ IDEOGRAPHIC DITTO MARK
*_ IDEOGRAPHIC ITERATION MARK
;_ IDEOGRAPHIC CLOSING MARK
0_ IDEOGRAPHIC NUMBER ZERO
   ....
   cell 010
<+ LEFT DOUBLE ANGLE BRACKET
>+ RIGHT DOUBLE ANGLE BRACKET
<' LEFT CORNER BRACKET
>' RIGHT CORNER BRACKET
<" LEFT WHITE CORNER BRACKET
>" RIGHT WHITE CORNER BRACKET
(" LEFT BLACK LENTICULAR BRACKET
)" RIGHT BLACK LENTICULAR BRACKET
=T POSTAL MARK
=_ GETA MARK
(' LEFT TORTOISE SHELL BRACKET
)' RIGHT TORTOISE SHELL BRACKET
(I LEFT WHITE LENTICULAR BRACKET
)I RIGHT WHITE LENTICULAR BRACKET
   ....
   cell 028
-? WAVE DASH
   cell 032
=T:) POSTAL MARK FACE

   row 048
   cell 065
A5 HIRAGANA LETTER SMALL A
a5 HIRAGANA LETTER A
I5 HIRAGANA LETTER SMALL I
i5 HIRAGANA LETTER I
U5 HIRAGANA LETTER SMALL U
u5 HIRAGANA LETTER U
E5 HIRAGANA LETTER SMALL E
e5 HIRAGANA LETTER E
O5 HIRAGANA LETTER SMALL O
o5 HIRAGANA LETTER O
ka HIRAGANA LETTER KA
ga HIRAGANA LETTER GA
ki HIRAGANA LETTER KI
gi HIRAGANA LETTER GI
ku HIRAGANA LETTER KU
gu HIRAGANA LETTER GU
ke HIRAGANA LETTER KE
ge HIRAGANA LETTER GE
ko HIRAGANA LETTER KO
go HIRAGANA LETTER GO
sa HIRAGANA LETTER SA
za HIRAGANA LETTER ZA
si HIRAGANA LETTER SI
zi HIRAGANA LETTER ZI
su HIRAGANA LETTER SU
zu HIRAGANA LETTER ZU
se HIRAGANA LETTER SE
ze HIRAGANA LETTER ZE
so HIRAGANA LETTER SO
zo HIRAGANA LETTER ZO
ta HIRAGANA LETTER TA
da HIRAGANA LETTER DA
ti HIRAGANA LETTER TI
di HIRAGANA LETTER DI
tU HIRAGANA LETTER SMALL TU
tu HIRAGANA LETTER TU
du HIRAGANA LETTER DU
te HIRAGANA LETTER TE
de HIRAGANA LETTER DE
to HIRAGANA LETTER TO
do HIRAGANA LETTER DO
na HIRAGANA LETTER NA
ni HIRAGANA LETTER NI
nu HIRAGANA LETTER NU
ne HIRAGANA LETTER NE
no HIRAGANA LETTER NO
ha HIRAGANA LETTER HA
ba HIRAGANA LETTER BA
pa HIRAGANA LETTER PA
hi HIRAGANA LETTER HI
bi HIRAGANA LETTER BI
pi HIRAGANA LETTER PI
hu HIRAGANA LETTER HU
bu HIRAGANA LETTER BU
pu HIRAGANA LETTER PU
he HIRAGANA LETTER HE
be HIRAGANA LETTER BE
pe HIRAGANA LETTER PE
ho HIRAGANA LETTER HO
bo HIRAGANA LETTER BO
po HIRAGANA LETTER PO
ma HIRAGANA LETTER MA
mi HIRAGANA LETTER MI
mu HIRAGANA LETTER MU
me HIRAGANA LETTER ME
mo HIRAGANA LETTER MO
yA HIRAGANA LETTER SMALL YA
ya HIRAGANA LETTER YA
yU HIRAGANA LETTER SMALL YU
yu HIRAGANA LETTER YU
yO HIRAGANA LETTER SMALL YO
yo HIRAGANA LETTER YO
ra HIRAGANA LETTER RA
ri HIRAGANA LETTER RI
ru HIRAGANA LETTER RU
re HIRAGANA LETTER RE
ro HIRAGANA LETTER RO
wA HIRAGANA LETTER SMALL WA
wa HIRAGANA LETTER WA
wi HIRAGANA LETTER WI
we HIRAGANA LETTER WE
wo HIRAGANA LETTER WO
n5 HIRAGANA LETTER N
vu HIRAGANA LETTER VU
   
   COMBINING KATAKANA-HIRAGANA VOICED SOUND MARK
   COMBINING KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
   cell 155
"5 KATAKANA-HIRAGANA VOICED SOUND MARK
05 KATAKANA-HIRAGANA SEMI-VOICED SOUND MARK
*5 HIRAGANA ITERATION MARK
+5 HIRAGANA VOICED ITERATION MARK

   cell 161
a6 KATAKANA LETTER SMALL A
A6 KATAKANA LETTER A
i6 KATAKANA LETTER SMALL I
I6 KATAKANA LETTER I
u6 KATAKANA LETTER SMALL U
U6 KATAKANA LETTER U
e6 KATAKANA LETTER SMALL E
E6 KATAKANA LETTER E
o6 KATAKANA LETTER SMALL O
O6 KATAKANA LETTER O
Ka KATAKANA LETTER KA
Ga KATAKANA LETTER GA
Ki KATAKANA LETTER KI
Gi KATAKANA LETTER GI
Ku KATAKANA LETTER KU
Gu KATAKANA LETTER GU
Ke KATAKANA LETTER KE
Ge KATAKANA LETTER GE
Ko KATAKANA LETTER KO
Go KATAKANA LETTER GO
Sa KATAKANA LETTER SA
Za KATAKANA LETTER ZA
Si KATAKANA LETTER SI
Zi KATAKANA LETTER ZI
Su KATAKANA LETTER SU
Zu KATAKANA LETTER ZU
Se KATAKANA LETTER SE
Ze KATAKANA LETTER ZE
So KATAKANA LETTER SO
Zo KATAKANA LETTER ZO
Ta KATAKANA LETTER TA
Da KATAKANA LETTER DA
Ti KATAKANA LETTER TI
Di KATAKANA LETTER DI
TU KATAKANA LETTER SMALL TU
Tu KATAKANA LETTER TU
Du KATAKANA LETTER DU
Te KATAKANA LETTER TE
De KATAKANA LETTER DE
To KATAKANA LETTER TO
Do KATAKANA LETTER DO
Na KATAKANA LETTER NA
Ni KATAKANA LETTER NI
Nu KATAKANA LETTER NU
Ne KATAKANA LETTER NE
No KATAKANA LETTER NO
Ha KATAKANA LETTER HA
Ba KATAKANA LETTER BA
Pa KATAKANA LETTER PA
Hi KATAKANA LETTER HI
Bi KATAKANA LETTER BI
Pi KATAKANA LETTER PI
Hu KATAKANA LETTER HU
Bu KATAKANA LETTER BU
Pu KATAKANA LETTER PU
He KATAKANA LETTER HE
Be KATAKANA LETTER BE
Pe KATAKANA LETTER PE
Ho KATAKANA LETTER HO
Bo KATAKANA LETTER BO
Po KATAKANA LETTER PO
Ma KATAKANA LETTER MA
Mi KATAKANA LETTER MI
Mu KATAKANA LETTER MU
Me KATAKANA LETTER ME
Mo KATAKANA LETTER MO
YA KATAKANA LETTER SMALL YA
Ya KATAKANA LETTER YA
YU KATAKANA LETTER SMALL YU
Yu KATAKANA LETTER YU
YO KATAKANA LETTER SMALL YO
Yo KATAKANA LETTER YO
Ra KATAKANA LETTER RA
Ri KATAKANA LETTER RI
Ru KATAKANA LETTER RU
Re KATAKANA LETTER RE
Ro KATAKANA LETTER RO
WA KATAKANA LETTER SMALL WA
Wa KATAKANA LETTER WA
Wi KATAKANA LETTER WI
We KATAKANA LETTER WE
Wo KATAKANA LETTER WO
N6 KATAKANA LETTER N
Vu KATAKANA LETTER VU
KA KATAKANA LETTER SMALL KA
KE KATAKANA LETTER SMALL KE
Va KATAKANA LETTER VA
Vi KATAKANA LETTER VI
Ve KATAKANA LETTER VE
Vo KATAKANA LETTER VO
.6 KATAKANA MIDDLE DOT
-6 KATAKANA-HIRAGANA PROLONGED SOUND MARK
*6 KATAKANA ITERATION MARK
+6 KATAKANA VOICED ITERATION MARK

   row 049
   cell 005
b4 BOPOMOFO LETTER B
p4 BOPOMOFO LETTER P
m4 BOPOMOFO LETTER M
f4 BOPOMOFO LETTER F
d4 BOPOMOFO LETTER D
t4 BOPOMOFO LETTER T
n4 BOPOMOFO LETTER N
l4 BOPOMOFO LETTER L
g4 BOPOMOFO LETTER G
k4 BOPOMOFO LETTER K
h4 BOPOMOFO LETTER H
j4 BOPOMOFO LETTER J
q4 BOPOMOFO LETTER Q
x4 BOPOMOFO LETTER X
zh BOPOMOFO LETTER ZH
ch BOPOMOFO LETTER CH
sh BOPOMOFO LETTER SH
r4 BOPOMOFO LETTER R
z4 BOPOMOFO LETTER Z
c4 BOPOMOFO LETTER C
s4 BOPOMOFO LETTER S
a4 BOPOMOFO LETTER A
o4 BOPOMOFO LETTER O
e4 BOPOMOFO LETTER E
eh4 BOPOMOFO LETTER EH
ai BOPOMOFO LETTER AI
ei BOPOMOFO LETTER EI
au BOPOMOFO LETTER AU
ou BOPOMOFO LETTER OU
an BOPOMOFO LETTER AN
en BOPOMOFO LETTER EN
aN BOPOMOFO LETTER ANG
eN BOPOMOFO LETTER ENG
er BOPOMOFO LETTER ER
i4 BOPOMOFO LETTER I
u4 BOPOMOFO LETTER U
iu BOPOMOFO LETTER IU
v4 BOPOMOFO LETTER V
nG BOPOMOFO LETTER NG
gn BOPOMOFO LETTER GN

   row 050
   cell 028
(JU) PARENTHESIZED HANGUL JU
   cell 032
1c PARENTHESIZED IDEOGRAPH ONE
2c PARENTHESIZED IDEOGRAPH TWO
3c PARENTHESIZED IDEOGRAPH THREE
4c PARENTHESIZED IDEOGRAPH FOUR
5c PARENTHESIZED IDEOGRAPH FIVE
6c PARENTHESIZED IDEOGRAPH SIX
7c PARENTHESIZED IDEOGRAPH SEVEN
8c PARENTHESIZED IDEOGRAPH EIGHT
9c PARENTHESIZED IDEOGRAPH NINE
10c PARENTHESIZED IDEOGRAPH TEN
   cell 127
KSC KOREAN STANDARD SYMBOL

   Presentation forms
   row 251
   cell 000
ff LATIN SMALL LIGATURE FF
fi LATIN SMALL LIGATURE FI
fl LATIN SMALL LIGATURE FL
ffi LATIN SMALL LIGATURE FFI
ffl LATIN SMALL LIGATURE FFL
ft LATIN SMALL LIGATURE FT
st LATIN SMALL LIGATURE ST

   row 254
   cell 125
3+; ARABIC SHADDA MEDIAL FORM
   cell 130
aM. ARABIC LETTER ALEF WITH MADDA ABOVE FINAL FORM
   cell 132
aH. ARABIC LETTER ALEF WITH HAMZA ABOVE FINAL FORM
   cell 141
a+- ARABIC LETTER ALEF ISOLATED FORM
a+. ARABIC LETTER ALEF FINAL FORM
b+- ARABIC LETTER BEH ISOLATED FORM
b+, ARABIC LETTER BEH INITIAL FORM
b+; ARABIC LETTER BEH MEDIAL FORM
b+. ARABIC LETTER BEH FINAL FORM
tm- ARABIC LETTER TEH MARBUTA ISOLATED FORM
tm. ARABIC LETTER TEH MARBUTA FINAL FORM
t+- ARABIC LETTER TEH ISOLATED FORM
t+, ARABIC LETTER TEH INITIAL FORM
t+; ARABIC LETTER TEH MEDIAL FORM
t+. ARABIC LETTER TEH FINAL FORM
tk- ARABIC LETTER THEH ISOLATED FORM
tk, ARABIC LETTER THEH INITIAL FORM
tk; ARABIC LETTER THEH MEDIAL FORM
tk. ARABIC LETTER THEH FINAL FORM
g+- ARABIC LETTER JEEM ISOLATED FORM
g+, ARABIC LETTER JEEM INITIAL FORM
g+; ARABIC LETTER JEEM MEDIAL FORM
g+. ARABIC LETTER JEEM FINAL FORM
hk- ARABIC LETTER HAH ISOLATED FORM
hk, ARABIC LETTER HAH INITIAL FORM
hk; ARABIC LETTER HAH MEDIAL FORM
hk. ARABIC LETTER HAH FINAL FORM
x+- ARABIC LETTER KHAH ISOLATED FORM
x+, ARABIC LETTER KHAH INITIAL FORM
x+; ARABIC LETTER KHAH MEDIAL FORM
x+. ARABIC LETTER KHAH FINAL FORM
d+- ARABIC LETTER DAL ISOLATED FORM
d+. ARABIC LETTER DAL FINAL FORM
dk- ARABIC LETTER THAL ISOLATED FORM
dk. ARABIC LETTER THAL FINAL FORM
r+- ARABIC LETTER REH ISOLATED FORM
r+. ARABIC LETTER REH FINAL FORM
z+- ARABIC LETTER ZAIN ISOLATED FORM
z+. ARABIC LETTER ZAIN FINAL FORM
s+- ARABIC LETTER SEEN ISOLATED FORM
s+, ARABIC LETTER SEEN INITIAL FORM
s+; ARABIC LETTER SEEN MEDIAL FORM
s+. ARABIC LETTER SEEN FINAL FORM
sn- ARABIC LETTER SHEEN ISOLATED FORM
sn, ARABIC LETTER SHEEN INITIAL FORM
sn; ARABIC LETTER SHEEN MEDIAL FORM
sn. ARABIC LETTER SHEEN FINAL FORM
c+- ARABIC LETTER SAD ISOLATED FORM
c+, ARABIC LETTER SAD INITIAL FORM
c+; ARABIC LETTER SAD MEDIAL FORM
c+. ARABIC LETTER SAD FINAL FORM
dd- ARABIC LETTER DAD ISOLATED FORM
dd, ARABIC LETTER DAD INITIAL FORM
dd; ARABIC LETTER DAD MEDIAL FORM
dd. ARABIC LETTER DAD FINAL FORM
tj- ARABIC LETTER TAH ISOLATED FORM
tj, ARABIC LETTER TAH INITIAL FORM
tj; ARABIC LETTER TAH MEDIAL FORM
tj. ARABIC LETTER TAH FINAL FORM
zH- ARABIC LETTER ZAH ISOLATED FORM
zH, ARABIC LETTER ZAH INITIAL FORM
zH; ARABIC LETTER ZAH MEDIAL FORM
zH. ARABIC LETTER ZAH FINAL FORM
e+- ARABIC LETTER AIN ISOLATED FORM
e+, ARABIC LETTER AIN INITIAL FORM
e+; ARABIC LETTER AIN MEDIAL FORM
e+. ARABIC LETTER AIN FINAL FORM
i+- ARABIC LETTER GHAIN ISOLATED FORM
i+, ARABIC LETTER GHAIN INITIAL FORM
i+; ARABIC LETTER GHAIN MEDIAL FORM
i+. ARABIC LETTER GHAIN FINAL FORM
f+- ARABIC LETTER FEH ISOLATED FORM
f+, ARABIC LETTER FEH INITIAL FORM
f+; ARABIC LETTER FEH MEDIAL FORM
f+. ARABIC LETTER FEH FINAL FORM
q+- ARABIC LETTER QAF ISOLATED FORM
q+, ARABIC LETTER QAF INITIAL FORM
q+; ARABIC LETTER QAF MEDIAL FORM
q+. ARABIC LETTER QAF FINAL FORM
k+- ARABIC LETTER KAF ISOLATED FORM
k+, ARABIC LETTER KAF INITIAL FORM
k+; ARABIC LETTER KAF MEDIAL FORM
k+. ARABIC LETTER KAF FINAL FORM
l+- ARABIC LETTER LAM ISOLATED FORM
l+, ARABIC LETTER LAM INITIAL FORM
l+; ARABIC LETTER LAM MEDIAL FORM
l+. ARABIC LETTER LAM FINAL FORM
m+- ARABIC LETTER MEEM ISOLATED FORM
m+, ARABIC LETTER MEEM INITIAL FORM
m+; ARABIC LETTER MEEM MEDIAL FORM
m+. ARABIC LETTER MEEM FINAL FORM
n+- ARABIC LETTER NOON ISOLATED FORM
n+, ARABIC LETTER NOON INITIAL FORM
n+; ARABIC LETTER NOON MEDIAL FORM
n+. ARABIC LETTER NOON FINAL FORM
h+- ARABIC LETTER HEH ISOLATED FORM
h+, ARABIC LETTER HEH INITIAL FORM
h+; ARABIC LETTER HEH MEDIAL FORM
h+. ARABIC LETTER HEH FINAL FORM
w+- ARABIC LETTER WAW ISOLATED FORM
w+. ARABIC LETTER WAW FINAL FORM
j+- ARABIC LETTER ALEF MAKSURA ISOLATED FORM
j+. ARABIC LETTER ALEF MAKSURA FINAL FORM
y+- ARABIC LETTER YEH ISOLATED FORM
y+, ARABIC LETTER YEH INITIAL FORM
y+; ARABIC LETTER YEH MEDIAL FORM
y+. ARABIC LETTER YEH FINAL FORM
lM- ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE ISOLATED FORM
lM. ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE FINAL FORM
lH- ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE ISOLATED FORM
lH. ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE FINAL FORM
lh- ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW ISOLATED FORM
lh. ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW FINAL FORM
la- ARABIC LIGATURE LAM WITH ALEF ISOLATED FORM
la. ARABIC LIGATURE LAM WITH ALEF FINAL FORM
