 
 &charset ISO_5428
 &rem source: ECMA registry
 &alias iso-ir-31
 &alias gr-bib
 &ecma x58
 &code 0
 NU SH SX EX ET EQ AK BL BS HT LF VT FF CR SO SI
 DL D1 D2 D3 D4 NK SY EB CN EM SB EC FS GS RS US
 SP "! "' __ "? __ __ __ __ ": "i __ __ __ __ __
 ?? ?? ?? ?? ?? __ __ __ __ ?? ?? __ __ __ __ ??
 ?? A* B* G* D* E* Z* Y* H* I* K* L* M* N* C* O*
 P* R* S* T* U* F* X* Q* W* .M << >> "9 "6 'G ,G
 ?? a* b* g* d* e* z* y* h* i* k* l* m* n* c* o*
 p* r* s* t* u* f* x* q* w* *s M3 K3 P3 T3 ?? ??
 
 &charset DIN_31624
 &rem source: ECMA registry
 &alias iso-ir-38
 &ecma x4f
 &code 0
 NU SH SX EX ET EQ AK BL BS HT LF VT FF CR SO SI
 DL D1 D2 D3 D4 NK SY EB CN EM SB EC FS GS RS US
 SP ! " Nb DO % & ' ( ) * + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ?
 SE A B C D E F G H I J K L M N O P Q R S T U V W X Y Z A: O: U: '> _ 
 '! a b c d e f g h i j k l m n o p q r s t u v w x y z a: o: u: ss DT
 PA HO BH NH IN NL SA ES HS HJ VS PD PU RI S2 S3
 DC P1 P2 TS CC MW SG EG SS GC SC CI ST OC PM AC
 NS !I __ Pd Cu %0 /- At DE <( (! << Mb Co Po Rg
 __ aS __ ?? // !! /= .M -> )> !) >> MX __ __ ?I
 __ "! "' "> "? "- "( ". ": "3 "0 __ __ "" __ "<
 "; __ __ __ __ __ __ __ "_ "= __ __ ?? __ __ __
 ?? AE D/ ?? ?? ?? ?? ?? L/ O/ OE ?? TH ?? ?? ??
 ?? ae d/ d- ?? i. ?? ?? l/ o/ oe yr th ?? ?? ??
  
 &charset DIN_31625
 &rem source: ECMA registry
 &alias iso-ir-39
 &ecma x4d
 &code 0
 NU SH SX EX ET EQ AK BL BS HT LF VT FF CR SO SI
 DL D1 D2 D3 D4 NK SY EB CN EM SB EC FS GS RS US
 SP
 __
 
 &charset ISO_5426:1980
 &rem source: ECMA registry
 &alias iso-ir-53
 &ecma x50
 &code 0
 NU SH SX EX ET EQ AK BL BS HT LF VT FF CR SO SI
 DL D1 D2 D3 D4 NK SY EB CN EM SB EC FS GS RS US
 SP ! " Nb Cu % & ' ( ) * + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ?
 At A B C D E F G H I J K L M N O P Q R S T U V W X Y Z <( // )> '> _ 
 '! a b c d e f g h i j k l m n o p q r s t u v w x y z (! !! !) '? DT
 PA HO BH NH IN NL SA ES HS HJ VS PD PU RI S2 S3
 DC P1 P2 TS CC MW SG EG SS GC SC CI ST OC PM AC
 NS !I :9 Pd DO Ye /- SE 1' '6 "6 << Mb Co Po Rg
 __ aS .9 ?? ?? ?? /= .M 2' '9 "9 >> MX '' '" ?I
 __ "! "' "> "? "- "( ". ": "3 "0 __ __ "" __ '<
 "; __ __ __ __ __ __ __ "_ "= __ __ ?? __ __ __
 ?? AE D/ ?? ?? ?? IJ ?? L/ O/ OE ?? TH ?? ?? ??
 ?? ae d/ d- ?? i. ij ?? l/ o/ oe ss th ?? ?? ??
 
 &charset codar-u
 &rem source: ECMA registry
 &alias iso-ir-59
 &ecma x5f
 &code 0
 NU SH SX EX ET EQ AK BL BS HT LF VT FF CR SO SI
 DL D1 D2 D3 D4 NK SY EB CN EM SB EC FS GS RS US
 SP ! " Nb Cu % & ' ( ) * + ,+ - . / 0 1 2 3 4 5 6 7 8 9 : ;+ < = > ?+
 At __ __ __ __ __ __ __ /+ :+ __ '+ "+ __ 1+ =+
 __ 0+ __ 3+ aH aM wH __ yH ah y+. p+ v+ gf H' a+
 b+ tm t+ tk g+ hk x+ d+ dk r+ z+ s+ sn c+ dd tj
 zH e+ i+ f+ q+ k+ l+ m+ n+ h+ w+ y+ !! j+ NO DT
 
 &charset APL
 &rem source: ECMA registry
 &alias iso-ir-68
 &ecma x65
 &code 0
 NU SH SX EX ET EQ AK BL BS HT LF VT FF CR SO SI
 DL D1 D2 D3 D4 NK SY EB CN EM SB EC FS GS RS US
 SP ': )  <  <= =  >  )> OR AN != -: ,  +  .  /
 0  1  2  3  4  5  6  7  8  9  (  <( ;  ?? :  //
 '- ?? ?? ?? ?? ?? _  ?? ?? i* ?? '  OS !! ?? ??
 *  ?  r* ?? ?? ?? ?? w* ?? -! ?? <- ?? -> >= -
 Dw A B C D E F G H I J K L M N O P Q R S T U V W X Y Z (! ?? !) DO DT
 __
 
 &charset mosaic-2
 &rem source: ECMA registry
 &alias iso-ir-71
 &ecma x63
 __
 
 &charset mosaic-3
 &rem source: ECMA registry
 &alias iso-ir-72
 &ecma x64
 __
 
 &charset T.101-G3
 &rem source: ECMA registry
 &alias iso-ir-129
 &ecma x7d
 __
 
 &charset T.101-DS1
 &rem source: ECMA registry
 &alias iso-ir-137
 &ecma x79
 __
 
 &charset IBM838
 &rem source: IBM 3174 Character Set Ref, GA27-3831-02, March 1990
 &alias cp838
 &alias ebcdic-cp-thai
 __
