
   Control characters
   Names according to ISO 2047 and ISO 6429:1988
   Acronyms for the 7-bit control codes taken from ISO 2047
   Acronyms for the 8-bit control codes taken if possible from 6429,
   else an abbrevation of the 6429 names not conflicting
   with other 6429 names.
   group 000
   plane 000
   row 000
   cell 000
NU NULL (NUL)
SH START OF HEADING (SOH)
SX START OF TEXT (STX)
EX END OF TEXT (ETX)
ET END OF TRANSMISSION (EOT)
EQ ENQUIRY (ENQ)
AK ACKNOWLEDGE (ACK)
BL BELL (BEL)
BS BACKSPACE (BS)
HT CHARACTER TABULATION (HT)
LF LINE FEED (LF)
VT LINE TABULATION (VT)
FF FORM FEED (FF)
CR CARRIAGE RETURN (CR)
SO SHIFT OUT (SO)
SI SHIFT IN (SI)
DL DATALINK ESCAPE (DLE)
D1 DEVICE CONTROL ONE (DC1)
D2 DEVICE CONTROL TWO (DC2)
D3 DEVICE CONTROL THREE (DC3)
D4 DEVICE CONTROL FOUR (DC4)
NK NEGATIVE ACKNOWLEDGE (NAK)
SY SYNCRONOUS IDLE (SYN)
EB END OF TRANSMISSION BLOCK (ETB)
CN CANCEL (CAN)
EM END OF MEDIUM (EM)
SB SUBSTITUTE (SUB)
EC ESCAPE (ESC)
FS FILE SEPARATOR (IS4)
GS GROUP SEPARATOR (IS3)
RS RECORD SEPARATOR (IS2)
US UNIT SEPARATOR (IS1)
   cell 127
DT DELETE (DEL)
PA PADDING CHARACTER (PAD)
HO HIGH OCTET PRESET (HOP)
BH BREAK PERMITTED HERE (BPH)
NH NO BREAK HERE (NBH)
IN INDEX (IND)
NL NEXT LINE (NEL)
SA START OF SELECTED AREA (SSA)
ES END OF SELECTED AREA (ESA)
HS CHARACTER TABULATION SET (HTS)
HJ CHARACTER TABULATION WITH JUSTIFICATION (HTJ)
VS LINE TABULATION SET (VTS)
PD PARTIAL LINE FORWARD (PLD)
PU PARTIAL LINE BACKWARD (PLU)
RI REVERSE LINE FEED (RI)
S2 SINGLE-SHIFT TWO (SS2)
S3 SINGLE-SHIFT THREE (SS3)
DC DEVICE CONTROL STRING (DCS)
P1 PRIVATE USE ONE (PU1)
P2 PRIVATE USE TWO (PU2)
TS SET TRANSMIT STATE (STS)
CC CANCEL CHARACTER (CCH)
MW MESSAGE WAITING (MW)
SG START OF GUARDED AREA (SPA)
EG END OF GUARDED AREA (EPA)
SS START OF STRING (SOS)
GC SINGLE GRAPHIC CHARACTER INTRODUCER (SGCI)
SC SINGLE CHARACTER INTRODUCER (SCI)
CI CONTROL SEQUENCE INTRODUCER (CSI)
ST STRING TERMINATOR (ST)
OC OPERATING SYSTEM COMMAND (OSC)
PM PRIVACY MESSAGE (PM)
AC APPLICATION PROGRAM COMMAND (APC)
