   Private use
   group 000
   plane 000
   row 224
   cell 000

__ indicates unfinished (Mnemonic)
/c JOIN THIS LINE WITH NEXT LINE (Mnemonic)

UA Unit space A (ISO-IR-8-1 064)
UB Unit space B (ISO-IR-8-1 096)
   The NON-SPACING entries are for convenience only, as they
   do not constitute a character, but are used as part of the
   coding for a character.
"3 NON-SPACING UMLAUT (ISO-IR-38 201) (not a real character)
"1 NON-SPACING DIAERESIS WITH ACCENT (ISO-IR-70 192) (not a real character)
"! NON-SPACING GRAVE ACCENT (ISO-IR-103 193) (not a real character)
"' NON-SPACING ACUTE ACCENT (ISO-IR-103 194) (not a real character)
"> NON-SPACING CIRCUMFLEX ACCENT (ISO-IR-103 195) (not a real character)
"? NON-SPACING TILDE (ISO-IR-103 196) (not a real character)
"- NON-SPACING MACRON (ISO-IR-103 197) (not a real character)
"( NON-SPACING BREVE (ISO-IR-103 198) (not a real character)
". NON-SPACING DOT ABOVE (ISO-IR-103 199) (not a real character)
": NON-SPACING DIAERESIS (ISO-IR-103 200) (not a real character)
"0 NON-SPACING RING ABOVE (ISO-IR-103 202) (not a real character)
"" NON-SPACING DOUBLE ACCUTE ACCENT (ISO-IR-103 204) (not a real character)
"< NON-SPACING CARON (ISO-IR-103 206) (not a real character)
", NON-SPACING CEDILLA (ISO-IR-103 203) (not a real character)
"; NON-SPACING OGONEK (ISO-IR-103 206) (not a real character)
"_ NON-SPACING LOW LINE (ISO-IR-103 204) (not a real character)
"= NON-SPACING DOUBLE LOW LINE (ISO-IR-38 217) (not a real character)
"/ NON-SPACING LONG SOLIDUS OVERLAY (ISO-IR-128 201) (not a real character)
"i GREEK NON-SPACING IOTA BELOW (ISO-IR-55 39) (not a real character)
"d GREEK NON-SPACING DASIA PNEUMATA (ISO-IR-55 38) (not a real character)
"p GREEK NON-SPACING PSILI PNEUMATA (ISO-IR-55 37) (not a real character)
;; GREEK DASIA PNEUMATA (ISO-IR-18 92)
,, GREEK PSILI PNEUMATA (ISO-IR-18 124)
b3 GREEK SMALL LETTER MIDDLE BETA (ISO-IR-18 99)
Ci CIRCLE (ISO-IR-83 0294)
f( FUNCTION SIGN (ISO-IR-143 221)
ed LATIN SMALL LETTER EZH (ISO-IR-158 142)
am ANTE MERIDIAM SIGN (ISO-IR-149 0267)
pm POST MERIDIAM SIGN (ISO-IR-149 0268)
Tel TEL COMPATIBILITY SIGN (ISO-IR-149 0269)
a+: ARABIC LETTER ALEF FINAL FORM COMPATIBILITY (IBM868 144)
Fl DUTCH GUILDER SIGN (IBM437 159)
GF GAMMA FUNCTION SIGN (ISO-10646-1DIS 032/032/037/122)
>V RIGHTWARDS VECTOR ABOVE (ISO-10646-1DIS 032/032/038/046)
!* GREEK VARIA (ISO-10646-1DIS 032/032/042/164)
?* GREEK PERISPOMENI (ISO-10646-1DIS 032/032/042/165)
J< LATIN CAPITAL LETTER J WITH CARON (the lowercase exist 000/000/001/240)
   The LAST entries are for convenience only for collating specification
a8 LATIN SMALL LETTER A WITH LAST (not a real character)
b8 LATIN SMALL LETTER B WITH LAST (not a real character)
c8 LATIN SMALL LETTER C WITH LAST (not a real character)
d8 LATIN SMALL LETTER D WITH LAST (not a real character)
e8 LATIN SMALL LETTER E WITH LAST (not a real character)
f8 LATIN SMALL LETTER F WITH LAST (not a real character)
g8 LATIN SMALL LETTER G WITH LAST (not a real character)
h8 LATIN SMALL LETTER H WITH LAST (not a real character)
i8 LATIN SMALL LETTER I WITH LAST (not a real character)
j8 LATIN SMALL LETTER J WITH LAST (not a real character)
k8 LATIN SMALL LETTER K WITH LAST (not a real character)
l8 LATIN SMALL LETTER L WITH LAST (not a real character)
m8 LATIN SMALL LETTER M WITH LAST (not a real character)
n8 LATIN SMALL LETTER N WITH LAST (not a real character)
o8 LATIN SMALL LETTER O WITH LAST (not a real character)
p8 LATIN SMALL LETTER P WITH LAST (not a real character)
q8 LATIN SMALL LETTER Q WITH LAST (not a real character)
r8 LATIN SMALL LETTER R WITH LAST (not a real character)
s8 LATIN SMALL LETTER S WITH LAST (not a real character)
t8 LATIN SMALL LETTER T WITH LAST (not a real character)
u8 LATIN SMALL LETTER U WITH LAST (not a real character)
v8 LATIN SMALL LETTER V WITH LAST (not a real character)
w8 LATIN SMALL LETTER W WITH LAST (not a real character)
x8 LATIN SMALL LETTER X WITH LAST (not a real character)
y8 LATIN SMALL LETTER Y WITH LAST (not a real character)
z8 LATIN SMALL LETTER Z WITH LAST (not a real character)
